# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .i_automated import IAutomated


class IAutomatedTableEditor(IAutomated):
    """ The IAutomatedTableEditor interface defines the API of automated
    editors that handle tables.
    """

    def simulate_select(self, id, delay, row, column):
        """ Simulate the user selecting an item.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param row:
            is the row of the item.
        :param column:
            is the column of the item.
        """

    def simulate_set(self, id, delay, value, row=None, column=None):
        """ Simulate the user setting the editor value for an item.

        :param id:
            is the (possibly scoped) identifier of the widget.  This is
            normally used in exceptions.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param value:
            is the value to set.  If this is a list or a tuple, and the
            ``column`` parameter is not set, then it is assumed to contain the
            values for the whole row.
        :param row:
            is the row of the item.  If it is ``None`` then it is assumed that
            an editor has already been opened for the item.
        :param column:
            is the column of the item.
        """
