# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QDialog, QWizard

from dip.model import implements, Model
from dip.ui import (CollectionButtons, Form, MessageArea, Stretch, TableWidget,
        VBox, Wizard, WizardPage)

from dip.builder import IApplicationTemplate

from .python_class import PythonClass


@implements(IApplicationTemplate)
class ApplicationTemplate(Model):
    """ The ApplicationTemplate class is the default implementation of an
    application template.
    """

    # The wizard used to get the input from the user.
    wizard = Wizard(
            WizardPage(
                VBox(
                    Form(
                        'script_name',
                        'script_description'
                    ),
                    Stretch(),
                    MessageArea()
                ),
                title="Application Script",
                subTitle="Enter the details of the script to create."
            ),
            WizardPage(
                VBox(
                    Form(
                        'plugin_manager.class_name',
                        'plugin_manager.module_name'
                    ),
                    Stretch(),
                    MessageArea()
                ),
                title="Plugin manager",
                subTitle="Enter the details of the plugin manager to use."
            ),
            WizardPage(
                VBox(
                    CollectionButtons('additional_plugins'),
                    TableWidget('additional_plugins',
                            columns=['class_name', 'module_name'],
                            row_factory=lambda: PythonClass(
                                    class_name="NewPluginClass",
                                    module_name="new.module")),
                    Stretch(),
                    MessageArea()
                ),
                title="Plugins",
                subTitle="Enter the details of the application plugins.  " \
                        "Order is important as some plugins may depend on " \
                        "others."
            ),
            WizardPage(
                VBox(
                    'whats_this_action',
                    Stretch(),
                    MessageArea()
                ),
                title="Additional actions",
                subTitle="Add any additional actions to the application."
            ),
            options=QWizard.NoBackButtonOnStartPage|QWizard.HaveFinishButtonOnEarlyPages
        )

    def populate(self, toolkit, title, parent):
        """ Populate the application template with input from the user.

        :param toolkit:
            is the toolkit to use for the user interface.
        :param title:
            is the title to use.
        :param parent:
            the parent widget of the user interface.
        :return:
            ``True`` if the template is populated.
        """

        ui = self.wizard(self, toolkit, parent=parent)
        ui.setWindowTitle(title)

        return ui.exec_() == QDialog.Accepted

    @IApplicationTemplate.additional_plugins.default
    def additional_plugins(self):
        """ Create the default list of additional plugins. """

        return [
                PythonClass(class_name='QtToolkitPlugin',
                        module_name='dip.ui.plugins'),
                PythonClass(class_name='IOManagerPlugin',
                        module_name='dip.io.plugins'),
                PythonClass(class_name='ShellManagerPlugin',
                        module_name='dip.shell.plugins'),
                PythonClass(class_name='QMainWindowShellPlugin',
                        module_name='dip.shell.plugins'),
                PythonClass(class_name='FilesystemPlugin',
                        module_name='dip.io.plugins')]

    @IApplicationTemplate.plugin_manager.default
    def plugin_manager(self):
        """ Create the default plugin manager. """

        return PythonClass(class_name='PluginManager',
                module_name='dip.plugins')
