# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import os

from dip.model import Str
from dip.shell import ITool
from dip.shell.actions import ShellAction

from dip.builder import IDipProject

from .application_template import ApplicationTemplate


class CreateApplicationAction(ShellAction):
    """ The CreateApplicationAction class implements a shell action that
    creates an application script.
    """

    # The identifier of the action.
    id = 'dip.builder.actions.create_application'

    # The title to be used for dialogs.
    _title = Str("Create application script")

    def perform(self, tool):
        """ Reimplemented to create the application.

        :param tool:
            is the tool.
        """

        project = ITool(tool).obj
        toolkit = self.shell.toolkit
        parent = self.shell.widget

        # Get the application template from the user.
        template = ApplicationTemplate()

        if not template.populate(toolkit, self._title, parent):
            return

        if os.path.exists(template.script_name):
            yes = toolkit.question(self._title,
                    "The file <tt>{0}</tt> already exists. Are you sure you "
                    "want to overwrite it?".format(template.script_name),
                    parent)

            if not yes:
                return

        try:
            project.create_application(template)
        except:
            import traceback

            toolkit.warning(self._title,
                    "There was an error creating the application.", parent,
                    traceback.format_exc())
            return

        toolkit.information(self._title,
                "The file <tt>{0}</tt> was created successfuly.".format(
                        template.script_name),
                parent)

    def validate(self, tool):
        """ Reimplemented to see if the action can be performed on the tool's
        object.  We don't care about the tool itself.

        :param tool:
            is the tool.
        :return:
            ``True`` if the action can be performed.
        """

        return isinstance(ITool(tool).obj, IDipProject)

    @ShellAction.text.default
    def text(self):
        """ Create the default action text. """

        return self._title + '...'
