# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Bool, List, Instance, Interface, Str

from .i_python_class import IPythonClass


class IApplicationTemplate(Interface):
    """ The IApplicationTemplate interface defines the data needed to create
    an application script.
    """

    # The list of additional plugins.
    additional_plugins = List(IPythonClass)

    # The plugin manager.
    plugin_manager = Instance(IPythonClass)

    # The application script's description.
    script_description = Str(
            toolTip="The short descriptive name of the script",
            whatsThis="This is the application script's short descriptive "
                    "name.  It will be passed to the QApplication constructor "
                    "and used in the window title of the application shell.")

    # The name of the application script.
    script_name = Str(validator=r'\S+',
            toolTip="The name of the script",
            whatsThis="This is the name of the application's executable "
                    "script.")

    # Set if the What's This action should be added.
    whats_this_action = Bool(label="What's This? action",
            toolTip="Add the standard \"What's This?\" action",
            whatsThis="The standard \"What's This?\" action will be created "
                    "and contributed to the 'dip.shell.actions' extension "
                    "point.")
