# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.plugins import ContributionTo, Plugin, Service
from dip.shell import IShell

from dip.builder import IDistributionsManager


class BuilderPlugin(Plugin):
    """ The BuilderPlugin class is the plugin definition for the dip
    application builder.
    """

    # The description of the plugin as it will appear to the user.
    description = "DIP application builder"

    # The identifier of the plugin.
    id = 'dip.builder'

    # The shell actions contributed by this plugin.
    actions = ContributionTo('dip.shell.actions')

    # The codecs contributed by this plugin.
    codecs = ContributionTo('dip.io.codecs')

    # The distributions manager service contributed by this plugin.
    distributions_manager_service = ContributionTo('dip.plugins.services')

    # The shell objects contributed by this plugin.
    objects = ContributionTo('dip.shell.objects')

    # The tools contributed by this plugin.
    tools = ContributionTo('dip.shell.tools')

    @actions.default
    def actions(self):
        """ Create the shell actions. """

        from dip.builder import BuildActionCollection
        from dip.builder.create_application import CreateApplicationAction

        shell = self.service(IShell)

        return [BuildActionCollection(),
                CreateApplicationAction(shell=shell)]

    @codecs.default
    def codecs(self):
        """ Create the codecs factories. """

        from dip.builder.project import DipProjectCodecsFactory

        return [DipProjectCodecsFactory()]

    @distributions_manager_service.default
    def distributions_manager_service(self):
        """ Create the distributions manager service. """

        from dip.builder.distributions import DistributionsManager

        distributions_manager = DistributionsManager()

        self.bind_extension_point('dip.builder.distributions',
                distributions_manager, 'distributions')

        return [Service(
                interface=IDistributionsManager,
                implementation=distributions_manager)]

    @objects.default
    def objects(self):
        """ Create the shell object factories. """

        from dip.builder.project import DipProjectFactory

        return [DipProjectFactory()]

    @tools.default
    def tools(self):
        """ Create the tool factories. """

        from dip.builder.project import DipProjectToolFactory

        return [DipProjectToolFactory()]
