# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.plugins import ContributionTo, Plugin
from dip.shell import IShell


class DistutilsPlugin(Plugin):
    """ The DistutilsPlugin class is the plugin definition for the plugin that
    builds a distutils distribution for an application.
    """

    # The description of the plugin as it will appear to the user.
    description = "DIP distutils distribution builder"

    # The identifier of the plugin.
    id = 'dip.builder.distributions.distutils'

    # The shell actions contributed by this plugin.
    actions = ContributionTo('dip.shell.actions')

    # The distribution types contributed by this plugin.
    distributions = ContributionTo('dip.builder.distributions')

    @actions.default
    def actions(self):
        """ Create the shell actions. """

        from dip.builder.distributions.distutils import DistutilsAction

        shell = self.service(IShell)

        return [DistutilsAction(shell=shell)]

    @distributions.default
    def distributions(self):
        """ Create the distributions. """

        from dip.builder.distributions.distutils import DistutilsDistribution

        return [DistutilsDistribution()]
