# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.io import ICodecsFactory
from dip.model import implements, Model

from dip.builder import IDipProject


@implements(ICodecsFactory)
class DipProjectCodecsFactory(Model):
    """ The DipProjectCodecsFactory class is the factory for the XML codecs
    used to serialise a project.
    """

    # The identifier of the format.
    id = 'dip.builder.formats.project'

    # The name of the format.
    name = "DIP Project"

    # The filter used with :class:`PyQt4.QtGui.QFileDialog`.
    filter = "DIP project files (*.dip)"

    def decodes(self, obj):
        """ Determine if the object can be decoded from XML.

        :param obj:
            is the object.
        :return:
            ``True`` if the object can be decoded.
        """

        return isinstance(obj, IDipProject)

    def decoder(self):
        """ A new instance of the object decoder is created and returned.

        :return:
            a new instance of the object decoder.
        """

        from .dip_project_xml_decoder import DipProjectXmlDecoder

        return DipProjectXmlDecoder(factory=self)

    def encodes(self, obj):
        """ Determine if the object can be encoded to XML.

        :param obj:
            is the object.
        :return:
            ``True`` if the object can be encoded.
        """

        return isinstance(obj, IDipProject)

    def encoder(self):
        """ A new instance of the object encoder is created and returned.

        :return:
            a new instance of the object encoder.
        """

        from .dip_project_xml_encoder import DipProjectXmlEncoder

        return DipProjectXmlEncoder(factory=self)
