# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import implements, Model
from dip.shell import IShellObjectFactory

from dip.builder import IDistributionsManager


@implements(IShellObjectFactory)
class DipProjectFactory(Model):
    """ The DipProjectFactory class is the factory for a :term:`shell object`
    that implements a dip project.
    """

    # The name of the type of the object.
    name = "DIP Project"

    # The identifier of a project's native format.
    native_format = 'dip.builder.formats.project'

    def __call__(self, shell):
        """ Create an instance of the shell object.

        :param shell:
            is the shell.

        :return:
            the instance of the shell object.
        """

        from .dip_project import DipProject

        distributions_manager = shell.plugin_manager.service(
                IDistributionsManager)

        return DipProject(distributions_manager=distributions_manager)
