# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.shell import ModelToolFactory
from dip.ui import FileSelector, Form, MessageArea, Stretch, TextEdit, VBox

from dip.builder import IDipProject


class DipProjectToolFactory(ModelToolFactory):
    """ The DipProjectToolFactory class is the factory for a :term:`tool` that
    allows a dip project to be edited.
    """

    # The name of the tool.
    name = "DIP Project Editor"

    # The sub-class of Model that the tool can handle.
    model_type = IDipProject

    def create_view_factory(self):
        """ Create the view factory that will create the view.

        :return:
            the view factory.
        """

        return VBox(
                Form(
                    'description',
                    'author',
                    'author_email',
                    'home_page',
                    TextEdit('file_header_text'),
                    FileSelector('package_directory', mode='directory')
                ),
                Stretch(),
                MessageArea()
            )
