# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.io import FormatError
from dip.io.codecs import XmlDecoder


class DipProjectXmlDecoder(XmlDecoder):
    """ The DipProjectXmlDecoder class implements the decoding from Xml of a
    project.
    """

    def decode_attribute(self, obj, reader, source, location):
        """ Decode the current element as an attribute.

        :param obj:
            is the object to populate from the decoded byte stream.
        :param reader:
            is the :class:`~PyQt4.QtCore.QXmlStreamReader` instance.
        :param source:
            is an iterator that will return the byte stream to be decoded.
        :param location:
            is the storage location where the encoded object is being read
            from.  It is mainly used for error reporting.
        """

        # See if the element needs any special handling.
        if reader.name() == 'defaults':
            distribution_id = reader.attributes().value('distribution')
            if distribution_id == '':
                raise FormatError(
                        "Element 'defaults' has no 'distribution' attribute")

            distribution = obj.distributions_manager.distribution(
                    distribution_id)
            if distribution is None:
                # FIXME: Save the XML so that it can be written back later if
                # FIXME: needed.
                raise ValueError(
                        "unknown distribution '{0}'".format(distribution_id))

            defaults = distribution.defaults_factory()
            self.decode_model(defaults, reader, source, location)

            obj.distributions_defaults.append(defaults)

        else:
            super(DipProjectXmlDecoder, self).decode_attribute(obj, reader, source, location)
