# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import functools

from PyQt4.QtGui import QTreeWidget, QTreeWidgetItem

from dip.model import List, Model, observe
from dip.plugins import IPlugin


class PluginsViewer(QTreeWidget, Model):
    """ The PluginsViewer class is a widget that implements a read-only
    visualisation of all plugins.
    """

    # The plugins being viewed.
    plugins = List(IPlugin)

    def __init__(self):
        """ Initialise the viewer. """

        super(PluginsView, self).__init__()

        self.setHeaderLabels(["Identifier", "Description", "Enabled"])

    @plugins.observer
    def plugins(self, change):
        """ Invoked when new plugins are added. """

        # At the moment plugins can only be added.
        for plugin in change.new:
            itm = QTreeWidgetItem(self,
                    [plugin.id, plugin.description,
                            "Yes" if plugin.enabled else "No"])

            observe('enabled', plugin,
                    functools.partial(self._plugin_state_changed, itm))

    def _plugin_state_changed(self, itm, change):
        """ Invoked when the enabled state of a plugin changes. """

        itm.setText(2, "Yes" if change.new else "No")
