# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QTreeWidget, QTreeWidgetItem

from dip.model import List, Model
from dip.plugins import IService


class ServicesViewer(QTreeWidget, Model):
    """ The ServicesViewer class is a widget that implements a read-only
    visualisation of all services.
    """

    # The services being viewed.
    services = List(IService)

    def __init__(self):
        """ Initialise the viewer. """

        super(ServicesViewer, self).__init__()

        self.setHeaderLabels(["Interface"])

    @services.observer
    def services(self, change):
        """ Invoked when new services are added. """

        # At the moment services can only be added.
        for service in change.new:
            interface_full_name = str(service.interface)

            for i in range(self.topLevelItemCount()):
                itm = self.topLevelItem(i)
                if itm.toolTip(0) == interface_full_name:
                    break
            else:
                itm = QTreeWidgetItem(self, [service.interface.__name__])
                itm.setToolTip(0, interface_full_name)

            QTreeWidgetItem(itm, [str(service.implementation)])
