# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


""" The :mod:`dip.io` module implements the infrastructure for defining and
interfacing with :term:`storage`.

Most of the functionality provided by the module is used by the rest of dip.

Applications will, typically, only need to define an implementation of the
:class:`~dip.io.ICodecsFactory` interface for the data the application wants
to store.  The :mod:`dip.io.codecs` module contains an appropriate XML decoder
and encoder which do much of the work if the data is to be stored as XML and
is implemented as a :class:`~dip.model.Model`.

dip includes support for using the filesystem as storage.  Some applications
or environments may also need to define additional types of storage.  This is
done by providing appropriate implementations of the
:class:`~dip.io.IStreamingStorageFactory` or
:class:`~dip.io.IStructuredStorageFactory` interfaces.
"""


from .i_codecs_factory import ICodecsFactory
from .i_decoder import IDecoder
from .i_encoder import IEncoder
from .i_format import IFormat
from .i_io_manager import IIOManager
from .i_storage import IStorage
from .i_storage_factory import IStorageFactory
from .i_storage_location import IStorageLocation
from .i_storage_policy import IStoragePolicy
from .i_storage_ui import IStorageUi
from .i_streaming_storage import IStreamingStorage
from .i_streaming_storage_factory import IStreamingStorageFactory
from .i_structured_storage import IStructuredStorage
from .i_structured_storage_factory import IStructuredStorageFactory

from .exceptions import FormatError, StorageError
