# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Instance, Interface

from .i_codecs_factory import ICodecsFactory


class IDecoder(Interface):
    """ The IDecoder interface defines the API of an object decoder. """

    # The codecs factory that created this decoder.
    factory = Instance(ICodecsFactory)

    def decode(self, obj, source, location):
        """ An object is decoded from a byte stream.

        :param obj:
            is the object to populate from the decoded byte stream.
        :param source:
            is an iterator that will return the byte stream to be decoded.
        :param location:
            is the storage location where the encoded object is being read
            from.  It is mainly used for error reporting.
        :return:
            the decoded object.  This may be the original object populated
            from the byte stream, or it may be a different object (of an
            appropriate type) created from the byte stream.
        """
