# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Instance, Interface

from .i_codecs_factory import ICodecsFactory


class IEncoder(Interface):
    """ The IEncoder interface defines the API of an object encoder. """

    # The codecs factory that created this encoder.
    factory = Instance(ICodecsFactory)

    def encode(self, obj, location):
        """ An object is encoded as a byte stream.  This should be implemented
        as a generator as it will be called in a loop.  This allows large
        objects to be encoded without requiring the whole byte stream to be
        held in memory.

        :param obj:
            is the object to encode.
        :param location:
            is the storage location where the encoded object will be written
            to.  It is mainly used for error reporting.
        :return:
            the next section of the encoded byte stream.
        """
