# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Interface, Str


class IFormat(Interface):
    """ The IFormat interface is implemented by objects that need to impose a
    format on an object to see if the object can be stored.
    """

    # The identifier of the format.
    id = Str()

    # The name of the format.
    name = Str()

    def decodes(self, obj):
        """ Determines if an object can be decoded from this format.

        :param obj:
            is the object.
        :return:
            ``True`` if the object can be decoded from this format.
        """

    def encodes(self, obj):
        """ Determines if an object can be encoded to this format.

        :param obj:
            is the object.
        :return:
            ``True`` if the object can be encoded to this format.
        """
