# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Instance, Interface

from .i_storage_factory import IStorageFactory
from .i_storage_ui import IStorageUi


class IStorage(Interface):
    """ The IStorage interface defines the API of a particular type of
    :term:`storage`.
    """

    # The storage factory that created this storage.
    factory = Instance(IStorageFactory)

    # The user interface used to obtain storage locations from the user.
    ui = Instance(IStorageUi)

    def explicit_location(self, location=''):
        """ If the storage has explicit storage locations (i.e. a location is
        independent on the value of an object) then convert such a location
        specified as a string to an :class:`~dip.io.IStorageLocation`
        instance.

        :param location:
            is the location as a string.  The string may be empty, but
            otherwise should be valid for the storage.
        :return:
            the :class:`~dip.io.IStorageLocation` instance or ``None`` if the
            storage does not have explicit storage locations.
        """

    def implicit_location(self, obj):
        """ If the storage has implicit storage locations (i.e. a location is
        dependent on the value of an object) then create such a location for
        an object.

        :param obj:
            is the object to create the location for.
        :return:
            the location or ``None`` if the storage does not have implicit
            storage locations.
        """

    def read(self, obj, location):
        """ Read an object from a storage location.

        :param obj:
            is the object to populate from the storage location.
        :param location:
            is the storage location where the object is read from.
        :return:
            the read object.  This may be the original object populated
            from the storage location, or it may be a different object (of an
            appropriate type) created from the storage location.
        """

    def write(self, obj, location):
        """ Write an object to a storage location.

        :param obj:
            is the object to write.
        :param location:
            is the storage location where the object is written to.
        """
