# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Instance, Interface


class IStorageUi(Interface):
    """ The IStorageUi interface defines the API used to implement the user
    interface that selects an explicit :term:`storage location`.
    """

    # The storage that this is the user interface for.
    storage = Instance('dip.io.IStorage')

    def read_browser(self, toolkit, location):
        """ Create a widget that allows the user to browse the storage and
        select a read location.

        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation that can be used to
            create the browser.
        :param location:
            is the location that is updated by the user.
        :return:
            the :class:`~PyQt4.QtGui.QWidget` that implements the browser.
        """

    def get_read_location(self, toolkit, location):
        """ Get an updated location from the user where an object should be
        read from.

        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation that can be used to
            create any user interface.
        :param location:
            is the location that is updated by the user.  If the user
            cancelled then its :attr:`~dip.io.IStorageLocation.location`
            attribute is set to an empty string.
        """

    def write_browser(self, toolkit, location):
        """ Create a widget that allows the user to browse the storage and
        select a write location.

        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation that can be used to
            create the browser.
        :param location:
            is the location that is updated by the user.
        :return:
            the :class:`~PyQt4.QtGui.QWidget` that implements the browser.
        """

    def get_write_location(self, toolkit, location):
        """ Get an updated location from the user where an object should be
        written to.

        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation that can be used to
            create any user interface.
        :param location:
            is the location that is updated by the user.  If the user
            cancelled then its :attr:`~dip.io.IStorageLocation.location`
            attribute is set to an empty string.
        """
