# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.io import IIOManager
from dip.plugins import ContributionTo, Plugin, Service


class IOManagerPlugin(Plugin):
    """ The IOManagerPlugin class is the plugin definition for the default i/o
    manager.
    """

    # The description of the plugin as it will appear to the user.
    description = "The default i/o manager"

    # The identifier of the plugin.
    id = 'dip.io.io_manager'

    # The i/o manager service contributed by this plugin.
    io_manager = ContributionTo('dip.plugins.services')

    @io_manager.default
    def io_manager(self):
        """ Create the i/o manager. """

        from dip.io.io_manager import IOManager

        io_manager = IOManager()

        self.bind_extension_point('dip.io.codecs', io_manager,
                'codecs_factories')
        self.bind_extension_point('dip.io.storage', io_manager,
                'storage_factories')

        return [Service(interface=IIOManager, implementation=io_manager)]
