# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QDir, QFile, QFileInfo

from dip.io import IStreamingStorage
from dip.io.storage import QIODeviceStorage
from dip.model import implements

from .filesystem_storage_location import FilesystemStorageLocation


@implements(IStreamingStorage)
class FilesystemStorage(QIODeviceStorage):
    """ The FilesystemStorage class implements :term:`streaming storage` based
    on a local filesystem.
    """

    def explicit_location(self, location=''):
        """ Create a filesystem storage location from a string.

        :param location:
            is the location as a string.  The string may be empty, but
            otherwise should be a valid filesystem name.
        :return:
            the storage location.
        """

        # Convert to an absolute name using native separators.
        if location != '':
            location = QFileInfo(location).absoluteFilePath()
            location = QDir.toNativeSeparators(location)

        return FilesystemStorageLocation(storage=self, location=location)

    def qiodevice(self, location):
        """ A storage location is converted to a
        :class:`~PyQt4.QtCore.QIODevice` instance, specifically a
        :class:`~PyQt4.QtCore.QFile`.

        :param location:
            is the storage location.
        :return:
            the :class:`~PyQt4.QtCore.QFile`.
        """

        return QFile(location.location)

    @IStreamingStorage.ui.default
    def ui(self):
        """ Return the default implementation of the storage user interface.
        """

        from .filesystem_storage_ui import FilesystemStorageUi

        return FilesystemStorageUi(storage=self)
