# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.io import IStreamingStorageFactory
from dip.model import implements, Model


@implements(IStreamingStorageFactory)
class FilesystemStorageFactory(Model):
    """ The FilesystemStorageFactory class is the factory for
    :term:`streaming storage` based on a filesystem.
    """

    # The name of the storage.
    name = "Filesystem"

    def __call__(self):
        """ A new instance of the filesystem storage is created and returned.

        :return:
            a new instance of the filesystem storage.
        """

        from .filesystem_storage import FilesystemStorage

        return FilesystemStorage(factory=self)

    def valid_location(self, location):
        """ Check if a location specified as a string is valid for this
        storage.

        :param location:
            is the location as a string.

        :return:
            ``True`` if the location is valid.
        """

        # Assume any non-empty string is valid.
        return location != ''
