# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


""" The :mod:`dip.model` module implements a declarative type system for
Python.

The core of the module is the :class:`~dip.model.Model` class.  Sub-classes
define attributes as class attributes using model type classes such as
:class:`~dip.model.Bool` and :class:`~dip.model.Str`.  When such a sub-class is
instantiated then corresponding instance attributes are automatically created.

A model will enforce an attribute's type when rebinding it to a different
value.  It will also apply any additional constraints imposed by a particular
type.  For example the :class:`~dip.model.Int` type can impose minimum and
maximum values.  All types can provide an default value (that may be
overridden) for an attribute.

The initial values of attributes can be delayed until they are actually
needed.  This can be used to implement the lazy loading of Python modules.

An attribute can be observed and arbitrary Python code invoked when its value
changes.

The :class:`~dip.model.MappingProxy` class can be used to adapt, with some
limitations, any Python mapping object to a model.

Most of the APIs described support the definition of new attribute types.  If
you simply want to see how to use existing types then you only need to look at
the ``__init__()`` methods of type classes.
"""


from .adapt import adapt
from .adapter import Adapter
from .any import Any
from .attribute_change import AttributeChange
from .bool import Bool
from .callable import Callable
from .change_trigger import ChangeTrigger, get_change_trigger
from .collection_type_factory import CollectionTypeFactory
from .delegated_to import DelegatedTo
from .dict import Dict
from .enum import Enum
from .exceptions import ValidationError, ValidationTypeError
from .float import Float
from .implements import implements
from .instance import Instance
from .int import Int
from .interface import Interface
from .isadapted import isadapted
from .list import List
from .mapping_proxy import MappingProxy
from .meta_interface import MetaInterface
from .meta_model import MetaModel
from .model import Model
from .model_utils import clone_model, get_attribute_type, get_model_types
from .mutable_type_factory import MutableTypeFactory
from .observe import observe
from .set import Set
from .str import Str
from .subclass import Subclass
from .trigger import Trigger
from .tuple import Tuple
from .type_factory import TypeFactory
from .value_type_factory import ValueTypeFactory
