# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .exceptions import ValidationError, ValidationTypeError
from .value_type_factory import ValueTypeFactory


class Float(ValueTypeFactory):
    """ The Float class encapsulates a Python float. """

    def __init__(self, default=0.0, **metadata):
        """ Initialise the object.

        :param default:
            the default value of the integer.
        :param \*\*metadata:
            is additional meta-data stored with the type.
        """

        super(Float, self).__init__(default, metadata)

    def validate(self, value):
        """ Validate a float according to the constraints.  An exception is
        raised if the float is invalid.

        :param value:
            the float to validate.
        :return:
            the validated float.
        """

        if not isinstance(value, float):
            try:
                value = float(value)
            except:
                raise ValidationTypeError(Float, float, value)

        return value
