# Copyright (c) 2009 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .exceptions import ValidationError, ValidationTypeError
from .value_type_factory import ValueTypeFactory


class Int(ValueTypeFactory):
    """ The Int class encapsulates a Python integer. """

    def __init__(self, default=0, **metadata):
        """ Initialise the object.

        :param default:
            the default value of the integer.
        :param \*\*metadata:
            is additional meta-data stored with the type.
        """

        super(Int, self).__init__(default, metadata)

    def validate(self, value):
        """ Validate an integer according to the constraints.  An exception is
        raised if the integer is invalid.

        :param value:
            the integer to validate.
        :return:
            the validated integer.
        """

        if not isinstance(value, int):
            try:
                value = int(value)
            except:
                raise ValidationTypeError(Int, int, value)

        return value
