# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QString

from .exceptions import ValidationTypeError
from .value_type_factory import ValueTypeFactory


class Str(ValueTypeFactory):
    """ The Str class encapsulates a Python string. """

    def __init__(self, default='', **metadata):
        """ Initialise the object.

        :param default:
            the default value of the string.
        :param \*\*metadata:
            is additional meta-data stored with the type.
        """

        super(Str, self).__init__(default, metadata)

    def validate(self, value):
        """ Validate a string according to the constraints.  An exception is
        raised if the string is invalid.

        :param value:
            the string to validate.
        :return:
            the validated string.
        """

        if isinstance(value, QString):
            value = unicode(value)
        elif not isinstance(value, basestring):
            raise ValidationTypeError(Str, basestring, value)

        return value
