# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .change_trigger import get_change_trigger
from .type_factory import TypeFactory


class Trigger(TypeFactory):
    """ The Trigger class represents an asynchronous event.  Attributes of
    this type can be observed and can be set to any value (which is then
    discarded).
    """

    def __init__(self, **metadata):
        """ Initialise the object.

        :param \*\*metadata:
            is additional meta-data stored with the type.
        """

        super(Trigger, self).__init__(metadata)

        self._observer_func = None

    def observer(self, observer_func):
        """ This is used to decorate a method that will be invoked when the
        value of a typed attribute changes.  The name of the method should be
        the same as the name of the attribute.
        """

        clone = self.__class__(**self.metadata)

        clone._observer_func = observer_func

        return clone

    def __set__(self, instance, value):
        """ Reimplemented to pull the trigger. """

        name = self.name
        trigger = get_change_trigger(instance, name)

        if trigger is not None:
            # Avoid a circular import.
            from .attribute_change import AttributeChange

            change = AttributeChange(model=instance, name=name, new=value,
                    old=None)
            trigger.changed.emit(change)
