# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.



class TypeFactory(object):
    """ The TypeFactory class is the base class for all classes that create
    attribute types.
    """

    def __init__(self, metadata):
        """ Initialise the object.

        :param metadata:
            is a dictionary of additional meta-data stored with the type.
        """

        super(TypeFactory, self).__init__()

        self.metadata = metadata

        # This will get set by the meta-type when the scoping class is
        # created.
        self.name = None

    def __get__(self, instance, owner):
        """ Raise an exception as there is no value to get. """

        raise AttributeError(
                "'{0}' attributes cannot be read".format(type(self).__name__))

    def __set__(self, instance, value):
        """ This must be reimplemented by a sub-class. """

        raise NotImplementedError

    def __delete__(self, instance):
        """ Raise an exception as attributes cannot be deleted. """

        raise AttributeError(
                "'{0}' attributes cannot be deleted".format(
                        type(self).__name__))
