# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Bool, Instance, Interface, Str

from .i_plugin_manager import IPluginManager


class IPlugin(Interface):
    """ The IPlugin interface defines the API of a :term:`plugin`. """

    # The description of the plugin as it will appear to the user.
    description = Str()

    # This is set if the plugin is enabled.
    enabled = Bool(False)

    # The identifier of the plugin.  Two plugins are considered equivalent if
    # their factories have the same identifier, even though the factories
    # themselves are different.
    id = Str()

    # The plugin manager that is managing this plugin.  It will be set by the
    # plugin manager when the plugin is registered.
    plugin_manager = Instance(IPluginManager)

    def bind_extension_point(self, id, obj, name):
        """ Bind an extension point to the attribute of an object.  The
        attribute must have an ``append()`` method.

        :param id:
            is the identifier of the extension point.
        :param obj:
            is the object containing the attribute that the extension point is
            bound to.
        :param name:
            is the name of the attribute that the extension point is bound to.
        """

    def enable(self):
        """ The plugin is enabled.  It should not be called if it is already
        enabled.
        """

    def service(self, interface):
        """ Get a service that implements a particular interface.

        :param interface:
            is the interface that the service must implement.
        :return:
            the service.  An exception is raised if there is no service
            available.
        """
