# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Interface


class IPluginManager(Interface):
    """ The IPluginManager interface defines the API of a
    :term:`plugin manager`.
    """

    def bind_extension_point(self, id, obj, name):
        """ Bind an extension point to the attribute of an object.  The
        attribute must have an ``append()`` method.

        :param id:
            is the identifier of the extension point.
        :param obj:
            is the object containing the attribute that the extension point is
            bound to.
        :param name:
            is the name of the attribute that the extension point is bound to.
        """

    def contribute(self, id, *contributions):
        """ Contribute some objects to an extension point.

        :param id:
            is the identifier of the extension point.
        :param \*contributions:
            are the contributions to make to the extension point.  The
            contributions are made one at a time.
        """

    def enable_plugins(self):
        """ All plugins that are not already enabled are enabled. """

    def service(self, interface):
        """ Get a service that implements a particular interface.

        :param interface:
            is the interface that the service must implement.
        :return:
            the service.  An exception is raised if there is no service
            available.
        """

    def choose_service(self, interface, services):
        """ Choose a particular service from a list of possible services.

        :param interface:
            is the interface that the service must implement.
        :param services:
            a list of contributed services to choose from.  This can be
            ignored.
        :return:
            the chosen service or ``None`` if one wasn't chosen.
        """
