# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Bool, Callable, Instance
from dip.ui import IQActionAction

from .i_shell import IShell


class IShellAction(IQActionAction):
    """ The IShellAction interface defines the API for an :term:`action` that
    changes its state according to the user's interaction with the containing
    shell.
    """

    # This is set if the action is enabled.  If
    # :meth:`~dip.shell.IShellAction.validate` returns ``False`` then the
    # action will be disabled irrespective of this value.
    enabled = Bool(True)

    # This is used by the default implementation of
    # :meth:`~dip.shell.IShellAction.validate` to specify the type of the
    # active tool that is valid for the action.  If it is not specified then
    # the active tool, so long as there is one, will always be considered
    # valid.
    handles = Instance(type)

    # This is set if the action requires there to be an active tool.  If this
    # is ``True`` then the action will be automatically disabled, and
    # :meth:`~dip.shell.IShellAction.validate` will never be called, if there
    # is no active tool.
    needs_tool = Bool(True)

    # The default implementation of :meth:`~dip.shell.IShellAction.perform`
    # calls this with the shell's active tool as its only argument.
    on_perform = Callable()

    # The shell.  This is normally set by the shell itself.
    shell = Instance(IShell)

    # This is set if the action is visible.
    visible = Bool(True)

    def perform(self, tool):
        """ Perform the action (probably) on a tool.  This will not be called
        if :meth:`~dip.shell.IShellAction.validate` returns ``False``.

        :param tool:
            is the tool.
        """

    def validate(self, tool):
        """ Check if the action can be performed on a tool.

        :param tool:
            is the tool.
        :return:
            ``True`` if the action can be performed.
        """
