# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QWidget

from dip.io import IIOManager
from dip.model import Instance, Interface, List

from .i_shell_object_factory import IShellObjectFactory
from .i_tool_factory import IToolFactory


class IShellManager(Interface):
    """ The IShellManager interface defines the API for a
    :term:`shell manager`.
    """

    # The currently active tool.
    active_tool = Instance(QWidget)

    # The :class:`~dip.io.IIOManager`.
    io_manager = Instance(IIOManager)

    # The shell.
    shell = Instance('dip.shell.IShell')

    # The available shell object factories.
    shell_object_factories = List(IShellObjectFactory)

    # The available tool factories.
    tool_factories = List(IToolFactory)

    def close(self, tool):
        """ Close a tool asking the user for help where necessary.

        :param tool:
            is the tool to close.
        :return:
            ``True`` if the user didn't cancel.
        """

    def new(self):
        """ Create a tool for a new shell object asking the user for help where
        necessary.

        :return:
            the tool or None if the user cancelled.
        """

    def open(self, location=''):
        """ Create a tool for a shell object read from storage asking the user
        for help where necessary.

        :param location:
            is the optional location of the object to open.
        :return:
            the object or None if the user cancelled.
        """

    def quit(self):
        """ Confirm that the user wants to quit given the state of any shell
        objects.

        :return:
            ``True`` if the user didn't cancel.
        """

    def save(self, tool):
        """ Write a shell object to storage at its current location asking the
        user for help where necessary.

        :param tool:
            is the tool operating on the shell object to write.
        """

    def save_as(self, tool):
        """ Write a shell object to storage at a new location asking the user
        for help where necessary.

        :param tool:
            is the tool operating on the shell object to write.
        """
