# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.io import IStorageLocation
from dip.model import Any, Bool, Instance

from .i_display import IDisplay
from .i_shell_object_factory import IShellObjectFactory


class IShellObject(IDisplay):
    """ The IShellObject interface defines the API of a :term:`shell object`.
    """

    # This is set if the object needs writing to storage if no changes are to
    # be lost.  It will be cleared automatically.
    dirty = Bool()

    # The factory that created the object.  It will be set automatically.
    factory = Instance(IShellObjectFactory)

    # The :term:`storage location` of the object.  It will be None if it is
    # not stored.  It will be updated automatically.
    location = Instance(IStorageLocation)

    # This is set if the object is valid and can be written to storage.
    valid = Bool(True)
