# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Interface, Str


class IToolFactory(Interface):
    """ The IToolFactory interface defines the API for :term:`tool` factories.
    """

    # The name of the tool.
    name = Str()

    def __call__(self, obj, toolkit):
        """ Create an instance of the tool.

        :param obj:
            is the obj on which the tool is to operate on.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation that can be used to
            create widgets.
        :return:
            the instance of the tool.  This must be a
            :class:`~PyQt4.QtGui.QWidget` instance and, therefore, can be
            adapted to the :class:`~dip.tools.ITool` interface.
        """

    def handles(self, obj):
        """ Check if the tool can handle an object.

        :param obj:
            is the object.
        :return:
            ``True`` if the tool can handle the object.
        """
