# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.plugins import ContributionTo, Plugin, Service
from dip.shell import IShell, IShellManager
from dip.ui import IToolkit


class QMainWindowShellPlugin(Plugin):
    """ The QMainWindowShellPlugin class is the plugin definition for the
    default :class:`~PyQt4.QtGui.QMainWindow` based shell.
    """

    # The identifier of the plugin.
    id = 'dip.shells.qmainwindow'

    # The description of the plugin as it will appear to the user.
    description = "The default QMainWindow shell"

    # The shell service contributed by this plugin.
    shell_service = ContributionTo('dip.plugins.services')

    @shell_service.default
    def shell_service(self):
        """ Create the shell service. """

        from dip.shell.shells.qmainwindow import QMainWindowShell

        shell_manager = self.service(IShellManager)
        toolkit = self.service(IToolkit)

        shell = QMainWindowShell(plugin_manager=self.plugin_manager,
                shell_manager=shell_manager, toolkit=toolkit)

        self.bind_extension_point('dip.shell.actions', shell, 'actions')

        return [Service(interface=IShell, implementation=shell)]
