# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.io import IIOManager
from dip.plugins import ContributionTo, Plugin, Service
from dip.shell import IShellManager
from dip.ui import IToolkit


class ShellManagerPlugin(Plugin):
    """ The ShellManagerPlugin class is the plugin definition for the default
    shell manager.
    """

    # The identifier of the plugin.
    id = 'dip.shell.shell_manager'

    # The description of the plugin as it will appear to the user.
    description = "The default shell manager"

    # The shell manager service contributed by this plugin.
    shell_manager_service = ContributionTo('dip.plugins.services')

    @shell_manager_service.default
    def shell_manager_service(self):
        """ Create the shell manager service. """

        from dip.shell.shell_manager import ShellManager

        io_manager = self.service(IIOManager)

        shell_manager = ShellManager(io_manager=io_manager)

        self.bind_extension_point('dip.shell.objects', shell_manager,
                'shell_object_factories')
        self.bind_extension_point('dip.shell.tools', shell_manager,
                'tool_factories')

        return [Service(
                interface=IShellManager, implementation=shell_manager)]
