# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QDialog, QWizard

from .wizard_pages import ListPage


class ImplicitStorageWizard(QWizard):
    """ The ImplicitStorageWizard is a wizard that gets the user to specify a
    storage that supports implicit storage locations.  The wizard only has a
    single page but we still use a wizard to be consistent.
    """

    def __init__(self, locations, parent):
        """ Initialise the wizard. """

        super(ImplicitStorageWizard, self).__init__(parent, windowTitle="Save",
                options=QWizard.NoBackButtonOnStartPage)

        self._page = _ImplicitStoragePage(self, locations)

    def exec_(self):
        """ Interact with the wizard and return the user choices. """

        if super(ImplicitStorageWizard, self).exec_() != QDialog.Accepted:
            return None

        return self._page.selected_location


class _ImplicitStoragePage(ListPage):
    """ An _ImplicitStoragePage is a wizard page that allows the user to
    select the storage for an object.
    """

    def __init__(self, wizard, locations):
        """ Initialise the page. """

        super(_ImplicitStoragePage, self).__init__(
                title="Choose a Destination",
                subTitle="From the list below choose the where you want to "
                        "write the object to.")

        self._locations = locations

        self.selected_location = None
        self.set_names(
                [location.storage.factory.name for location in locations])

        self.id = wizard.addPage(self)

    def name_selected(self, name):
        """ Invoked when a storage name is selected. """

        # Update the selected location according to the name.
        for location in self._locations:
            if location.storage.factory.name == name:
                self.selected_location = location
                break
