# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import (QAbstractItemView, QDialog, QDialogButtonBox, QLabel,
        QListView, QStringListModel, QVBoxLayout)


class QuitConfirmationDialog(QDialog):
    """ Ask the user to confirm they want to quit when there are a number of
    dirty objects.
    """

    def __init__(self, names, parent):
        """ Initialise the dialog.

        :param names:
            is the list of names of the dirty objects.
        :param parent:
            is the parent widget.
        """

        super(QuitConfirmationDialog, self).__init__(parent=parent,
                windowTitle="Quit")

        layout = QVBoxLayout()

        w = QLabel("The following have been modified and all changes will be "
                "lost.  Do you still want to quit the application?",
                wordWrap=True)
        layout.addWidget(w)

        model = QStringListModel(names)
        model.sort(0)

        w = QListView(editTriggers=QAbstractItemView.NoEditTriggers,
                selectionMode=QAbstractItemView.NoSelection)
        w.setModel(model)
        layout.addWidget(w)

        w = QDialogButtonBox()
        w.addButton(QDialogButtonBox.Yes).setAutoDefault(False)
        w.addButton(QDialogButtonBox.No).setDefault(True)
        w.accepted.connect(self.accept)
        w.rejected.connect(self.reject)
        layout.addWidget(w)

        self.setLayout(layout)
