# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QDialog, QWizard

from .wizard_pages import ListPage, LocationPage


class SaveAsWizard(QWizard):
    """ The SaveAsWizard is a wizard that gets the user to specify a storage
    location where an object should be written to.
    """

    def __init__(self, shell_manager, obj, storage_list, default_location, parent):
        """ Initialise the wizard. """

        super(SaveAsWizard, self).__init__(parent, windowTitle="Save As",
                options=QWizard.IndependentPages|QWizard.NoBackButtonOnStartPage)

        self._obj = obj

        self._location_page = _WriteLocationPage(self, shell_manager.toolkit,
                default_location)
        self._storage_page = _WriteStoragePage(self, storage_list,
                self._location_page)

        self.setStartId(self._storage_page.id)

    def exec_(self):
        """ Interact with the wizard and return the user choices. """

        if super(SaveAsWizard, self).exec_() != QDialog.Accepted:
            return None

        return self._location_page.get_location()

    def nextId(self):
        """ Reimplemented to determine the id of the next page. """

        next_page_id = -1

        if self.currentPage() is self._storage_page:
            if self._storage_page.selected_storage.implicit_location(self._obj) is None:
                next_page_id = self._location_page.id


        return next_page_id


class _WriteLocationPage(LocationPage):
    """ A _WriteLocationPage is a base class for a wizard page that is embeds
    the widget supplied by storage to select a write location.
    """

    def __init__(self, wizard, toolkit, default_location):
        """ Initialise the page. """

        super(_WriteLocationPage, self).__init__(wizard, toolkit,
                default_location,
                "Choose the location in storage were you want to write the "
                "object to.")

    def get_browser(self, ui, location):
        """ Return the browser widget. """

        return ui.write_browser(self.toolkit, location)


class _WriteStoragePage(ListPage):
    """ A _WriteStoragePage is a wizard page that allows the user to select the
    storage for an object.
    """

    def __init__(self, wizard, storage_list, location_page):
        """ Initialise the page. """

        super(_WriteStoragePage, self).__init__(title="Choose a Destination",
                subTitle="From the list below choose the where you want to "
                        "write the object to.")

        self._storage_list = storage_list
        self._location_page = location_page

        location_page.set_storage_list(storage_list)

        self.selected_storage = None
        self.set_names(
                [storage.factory.name for storage in storage_list])

        self.id = wizard.addPage(self)

    def name_selected(self, name):
        """ Invoked when a storage name is selected. """

        # Update the selected location according to the name.
        for storage in self._storage_list:
            if storage.factory.name == name:
                self.selected_storage = storage
                self._location_page.set_storage(storage)
                break
