# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


""" The :mod:`dip.ui` module contains a collection of classes that allow a
PyQt user interface, or just a part of a user interface, to be defined
declaratively.

A user interface is declared as a hierachy of :term:`views<view>` that are
containers for :term`editor` factories and other views.  A particular view will
arrange its editors or sub-views in a certain way.  An editor allows a
particular attribute of a :term:`model` to be displayed and possibly updated.

Editors are testable, i.e. they can be controlled programmatically to simulate
the actions of a user so that user interfaces can be automatically tested to
ensure that the underlying model is changes as expected.

Views may also include ordinary Qt widgets and layouts and designs created with
Qt Designer.  Views may also be treated as ordinary Qt widgets and layouts in a
larger user interface.

It is not the intention to enable any user interface to be defined
declaratively, or to provide the same level of control provided by PyQt
itself.  The purpose of this module is to allow "boring" user interfaces (e.g.
those used for data entry) to be created very easily, or to provide an initial
user interface that will be replaced by something more specific at a later
stage of an application's development.
"""


from .i_action import IAction
from .i_check_box_editor import ICheckBoxEditor
from .i_collection_editor import ICollectionEditor
from .i_combo_box_editor import IComboBoxEditor
from .i_composite_view import ICompositeView
from .i_editor import IEditor
from .i_file_selector_editor import IFileSelectorEditor
from .i_float_spin_box_editor import IFloatSpinBoxEditor
from .i_line_edit_editor import ILineEditEditor
from .i_list_widget_editor import IListWidgetEditor
from .i_message_area import IMessageArea
from .i_push_button_editor import IPushButtonEditor
from .i_qaction_action import IQActionAction
from .i_radio_buttons_editor import IRadioButtonsEditor
from .i_spin_box_editor import ISpinBoxEditor
from .i_table_widget_editor import ITableWidgetEditor
from .i_text_edit_editor import ITextEditEditor
from .i_tool_button_editor import IToolButtonEditor
from .i_toolkit import IToolkit
from .i_view import IView
from .i_controller import IController

from .action import Action
from .action_collection import ActionCollection
from .add_button import AddButton
from .base_editor_adapter import BaseEditorAdapter
from .base_menu import BaseMenu
from .base_toolkit import BaseToolkit
from .base_validator import BaseValidator
from .base_view_adapter import BaseViewAdapter
from .bindings import Bindings
from .box_layout_factory import BoxLayoutFactory
from .check_box import CheckBox
from .collection_buttons import CollectionButtons
from .combo_box import ComboBox
from .composite_view_factory import CompositeViewFactory
from .controller import Controller
from .designer import Designer
from .dialog import Dialog
from .directory_validator import DirectoryValidator
from .down_button import DownButton
from .editor_factory import EditorFactory
from .file_selector import FileSelector
from .file_validator import FileValidator
from .float_spin_box import FloatSpinBox
from .form import Form
from .group_box import GroupBox
from .h_box import HBox
from .layout_factory import LayoutFactory
from .line_edit import LineEdit
from .linked_view_factory import LinkedViewFactory
from .list_column import ListColumn
from .list_widget import ListWidget
from .menu import Menu
from .menu_bar import MenuBar
from .message_area import MessageArea
from .push_button import PushButton
from .qobject_factory import QObjectFactory
from .radio_buttons import RadioButtons
from .remove_button import RemoveButton
from .single_subview_factory import SingleSubviewFactory
from .spin_box import SpinBox
from .splitter import Splitter
from .stretch import Stretch
from .table_column import TableColumn
from .table_widget import TableWidget
from .text_edit import TextEdit
from .tool_button import ToolButton
from .up_button import UpButton
from .v_box import VBox
from .view_factory import ViewFactory
from .wizard import Wizard
from .wizard_controller import WizardController
from .wizard_page import WizardPage
