# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QObject

from dip.model import Callable, implements, Instance, Model

from .i_qaction_action import IQActionAction


@implements(IQActionAction)
class Action(Model):
    """ The Action class implements an :term:`action` implemented, by default,
    as a :class:`~PyQt4.QtGui.QAction`.
    """

    # The optional parent.
    parent = Instance(QObject)

    # The callable invoked when the action is triggered.
    triggered = Callable()

    @IQActionAction.action.default
    def action(self):
        """ The default action. """

        from PyQt4.QtGui import QAction

        action = QAction(self.text, self.parent, objectName=self.id,
                statusTip=self.statusTip, toolTip=self.toolTip)

        if self.shortcut is not None:
            action.setShortcut(self.shortcut)

        if self.triggered is not None:
            action.triggered.connect(self.triggered)

        return action
