# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .i_collection_editor import ICollectionEditor
from .linked_view_factory import LinkedViewFactory


class AddButton(LinkedViewFactory):
    """ The AddButton class implements a factory for a button for adding to a
    collection editor.
    """

    # The suffix to add to the identifier to distinguish it from other linked
    # views.
    id_suffix = '.add'

    def create_view(self, controller, toolkit, parent):
        """ Create the view.

        :param controller:
            is the controller.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            view.
        :param parent:
            is the optional parent widget.
        :return:
            the view which will be an instance of
            :class:`~PyQt4.QtGui.QAbstractButton`.
        """

        view = toolkit.add_button(self, parent)
        self.bind(view, controller, toolkit)

        return view

    def link(self, view, editor):
        """ This is reimplemented to link the button view to the collection
        editor.

        :param view:
            is the view.
        :param editor:
            is the editor.
        """

        if not view.isEnabled():
            return

        view.clicked.connect(lambda: ICollectionEditor(editor).add())
