# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Any

from .i_editor import IEditor
from .base_view_adapter import BaseViewAdapter


class BaseEditorAdapter(BaseViewAdapter):
    """ The BaseEditorAdapter class is a base class for adapters than implement
    the :class:`~dip.ui.IEditor` interface for Qt widgets.
    """

    # The Qt signal that is emitted when the user changes the editor's value.
    change_signal = Any()

    def configure(self):
        """ Configure the view.  This is called when everything else has been
        set up.
        """

        self.factory.configure_editor(self.adaptee, self.attribute_type)

    def remove_label(self):
        """ Remove an editor's label.  This will only be called if the label
        policy is 'optional'.  This default implementation does nothing.
        """

    @IEditor.controller.observer
    def controller(self, change):
        """ Invoked when the controller changes. """

        signal = self.change_signal

        if signal is not None:
            if change.old is not None and change.new is None:
                signal.disconnect(self._editor_changed)

            if change.old is None and change.new is not None:
                signal.connect(self._editor_changed)

    @IEditor.enabled.setter
    def enabled(self, enabled):
        """ The setter for the enabled state. """

        self.adaptee.setEnabled(enabled)

    @IEditor.label.default
    def label(self):
        """ Return the default label. """

        return self.factory.get_attribute_label(self.attribute_type)

    def _editor_changed(self):
        """ Invoked when the editor's value changes. """

        self.controller.editor_changed(self.adaptee)
