# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .add_button import AddButton
from .down_button import DownButton
from .h_box import HBox
from .remove_button import RemoveButton
from .stretch import Stretch
from .up_button import UpButton


class CollectionButtons(HBox):
    """ The CollectionButtons class contains the standard buttons used to
    manipulate a collection editor.  Use the buttons separately if you want to
    lay them out differently.
    """

    def __init__(self, linked_to, **properties):
        """ Initialise the item.

        :param linked_to:
            is the identifier of the editor that each button is linked to.
        :param \*\*properties:
            are keyword arguments used as property names and values that are
            applied to the view.
        """

        super(CollectionButtons, self).__init__(Stretch(), UpButton(linked_to),
                DownButton(linked_to), AddButton(linked_to),
                RemoveButton(linked_to), **properties)
