# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QDialogButtonBox

from dip.model import Instance

from .single_subview_factory import SingleSubviewFactory


class Dialog(SingleSubviewFactory):
    """ The Dialog class implements a :class:`~PyQt4.QtGui.QDialog` based
    dialog.
    """

    # The buttons to display.
    buttons = Instance(QDialogButtonBox.StandardButtons)

    def create_view(self, controller, toolkit, parent):
        """ Create the view.

        :param controller:
            is the controller.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            view.
        :param parent:
            is the optional parent widget.
        :return:
            the :class:`~PyQt4.QtGui.QLayout` or :class:`~PyQt4.QtGui.QWidget`
            that is the root of the view's implementation.
        """

        # Create the contents.  This will be a list of one element.
        subviews = self.create_subviews(controller, toolkit, None)

        view = toolkit.dialog(self, subviews[0], parent)
        self.bind(view, controller, toolkit)

        return view

    def create_controller(self):
        """ Create an implementation of :class:`~dip.ui.IController`.

        :return:
            the controller.
        """

        from .controller import Controller

        # Delay the updating of the model until the dialog is accepted.
        return Controller(auto_update_model=False)

    @buttons.default
    def buttons(self):
        """ Return the default buttons. """

        return QDialogButtonBox.Ok|QDialogButtonBox.Cancel

    @SingleSubviewFactory.id.default
    def id(self):
        """ The default value of id. """

        return 'dip.dialog'
