# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Callable, Enum, Str

from .i_file_selector_editor import IFileSelectorEditor
from .directory_validator import DirectoryValidator
from .editor_factory import EditorFactory
from .file_validator import FileValidator


class FileSelector(EditorFactory):
    """ The FileSelector class implements a file (and directory) selector
    editor factory.
    """

    # The filter string in the format used by
    # :class:`~PyQt4.QtGui.QFileDialog`.
    filter = Str()

    # The mode of the file selector.  'open_file' means a single, existing file
    # will be obtained.  'save_file' means that a single file that may or may
    # not exist will be obtained.  'directory' means a single, existing
    # directory will be obtained.
    mode = Enum('open_file', 'save_file', 'directory')

    # The validator factory.  This is called and passed a parent
    # :class:`~PyQt4.QtCore.QObject` and should return a
    # :class:`~PyQt4.QtGui.QValidator` instance.  If
    # :attr:`~dip.ui.FileSelector.mode` is 'open_file' then the default is
    # :class:`~dip.ui.FileValidator`.  If it is 'directory' then the default is
    # :class:`~dip.ui.DirectoryValidator`.
    validator = Callable()

    # The specific interface that the view implements.
    view_interface = IFileSelectorEditor

    def create_editor(self, attribute_type, toolkit, parent):
        """ Create the editor.

        :param attribute_type:
            the type of the attribute the factory is being asked to handle.  It
            should be a :class:`~dip.model.Str`.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            editor.
        :param parent:
            is the optional parent widget.
        :return:
            the editor.
        """

        return toolkit.file_selector(self, attribute_type, parent)

    @validator.default
    def validator(self):
        """ Return the default validator factory. """

        if self.mode == 'open_file':
            return FileValidator

        if self.mode == 'directory':
            return DirectoryValidator

        return None
