# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import isadapted

from .i_editor import IEditor
from .layout_factory import LayoutFactory


class Form(LayoutFactory):
    """ The Form class arranges its contents as a form. """

    def create_layout(self, items, toolkit):
        """ Create a layout for a form sub-view.

        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            horizontal box layout.
        :param attribute_type:
            is ``None`` in this context.
        :return:
            the :class:`~PyQt4.QtGui.QLayout` instance that is the view's
            implementation.
        """

        label_field = []

        for field in items:
            label = None

            if isadapted(field, IEditor):
                ieditor = IEditor(field)

                label_policy = ieditor.label_policy

                if label_policy == 'optional':
                    ieditor.remove_label()

                if label_policy != 'embedded':
                    label = ieditor.label

            label_field.append((label, field))

        return toolkit.form(self, label_field)
