# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QModelIndex

from dip.model import Int, List

from .i_editor import IEditor


class ICollectionEditor(IEditor):
    """ The ICollectionEditor interface defines the API to be implemented
    (typically using adaptation) by an editor created by an
    :class:`~dip.ui.EditorFactory` that handles a collection type (e.g. a
    list).
    """

    # The number of items in the collection.  This can only be read.
    item_count = Int()

    # The current selection.
    selection = List(QModelIndex)

    def add(self, value=None, edit=True):
        """ Add a new item to the collection.

        :param value:
            is the value of the item.  If it is ``None`` then an appropriate
            value will be created automatically.
        :param edit:
            is set if an editor should be open automatically for the new item.
        """

    def item_invalid_reason(self, index, invalid_reason):
        """ Update the invalid reason for an item in the collection.

        :param index:
            is the :class:`~PyQt4.QtCore.QModelIndex` of the item.
        :param index:
            is the invalid reason.  It will be an empty string if the item is
            valid.
        """

    def move_down(self, index):
        """ Move an item down.

        :param index:
            is the :class:`~PyQt4.QtCore.QModelIndex` of the item.
        """

    def move_up(self, index):
        """ Move an item up.

        :param index:
            is the :class:`~PyQt4.QtCore.QModelIndex` of the item.
        """

    def remove(self, indexes):
        """ Remove a number of items from the collection.

        :param indexes:
            is the list of :class:`~PyQt4.QtCore.QModelIndex` defining the
            items to be removed.
        """
