# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QLayout, QWidget

from dip.model import Bool, Instance, Interface, List, Model, Str

from .i_message_area import IMessageArea


class IController(Interface):
    """ The IController interface defines the API to be implemented by a
    :term:`view's<view>` :term:`controller`.
    """

    # This determines if the controller should automatically update the model
    # when the user changes the value of an editor (and the controller
    # determines that the view is valid).
    auto_update_model = Bool(True)

    # This explains why the view is invalid.  It will be an empty string if
    # the view is valid.
    invalid_reason = Str()

    # The message areas for giving feedback to the user.
    message_areas = List(IMessageArea)

    # The model.
    model = Instance(Model)

    # The view.
    view = Instance(QLayout, QWidget)

    def add_editor(self, editor):
        """ Add an editor to the controller.

        :param editor:
            is the editor.
        """

    def editor_changed(self, editor):
        """ This is called by an editor when the user has changed its value.

        :param editor:
            is the editor.
        """

    def find_editor(self, id):
        """ Find the editor with a specific identifier.

        :param id:
            is the identifier of the editor.
        :return:
            the editor or ``None`` if the view has no such editor.
        """

    def update_model(self):
        """ Update the all the attributes of a model that have a corresponding
        editor.
        """

    def validate(self):
        """ Validate the view and update the explanation as to why it is (or
        isn't) invalid.
        """

    def validate_view(self):
        """ Validate the data in the view.

        :return:
            a string which will be empty if the view is valid, otherwise it
            will explain why the view is invalid.
        """

    def __getattr__(self, name):
        """ Reimplemented to get an instance attribute allowing for names in
        the form 'attr_editor' where 'attr' is the name of a model attribute.
        """
