# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Any, Enum

from .i_line_edit_editor import ILineEditEditor
from .editor_factory import EditorFactory


class LineEdit(EditorFactory):
    """ The LineEdit class implements a line editor editor factory for string
    attributes.
    """

    # This specifies whether or not a value is required.  It is applied after
    # any validator has determined that the value is valid.  'meta-data' means
    # that the behavior is determined by any corresponding attribute in the
    # meta-data of the model type that the factory is bound to.  'no' means
    # that a value is not required (i.e. it can be an empty string).  'yes'
    # means that a value is required.  'stripped' means that a value with no
    # leading or trailing whitespace is required.  If 'meta-data' is specified,
    # but there is no corresponding meta-data then 'no' is assumed.
    required = Enum('meta-data', 'no', 'yes', 'stripped')

    # The validator which is either a string or a callable.  If it is a string
    # then it is assumed to be a Qt regular expression and a
    # :class:`~PyQt4.QtGui.QRegExpValidator` is created automatically.
    # Otherwise it is called and passed a parent :class:`~PyQt4.QtCore.QObject`
    # and should return a :class:`~PyQt4.QtGui.QValidator` instance.
    validator = Any()

    # The specific interface that the view implements.
    view_interface = ILineEditEditor

    def create_editor(self, attribute_type, toolkit, parent):
        """ Create the editor.

        :param attribute_type:
            the type of the attribute the factory is being asked to handle.  It
            should be a :class:`~dip.model.Str`.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            editor.
        :param parent:
            is the optional parent widget.
        :return:
            the editor.
        """

        return toolkit.line_edit(self, attribute_type, parent)
