# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import Qt

from dip.model import Enum, Instance

from .i_radio_buttons_editor import IRadioButtonsEditor
from .editor_factory import EditorFactory


class RadioButtons(EditorFactory):
    """ The RadioButtons class implements a radio buttons editor factory for
    enum attributes.
    """

    # The style of any frame.  'full' is a surrounding frame with the label
    # embeded.  'flat' is a partial frame with the label embedded.  'none' is
    # no frame.
    frame = Enum('full', 'flat', 'none')

    # The orientation of the radio buttons.
    orientation = Instance(Qt.Orientation, default=Qt.Vertical)

    # The specific interface that the view implements.
    view_interface = IRadioButtonsEditor

    def create_editor(self, attribute_type, toolkit, parent):
        """ Create the editor.

        :param attribute_type:
            the type of the attribute the factory is being asked to handle.  It
            should be an :class:`~dip.model.Enum`.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            editor.
        :param parent:
            is the optional parent widget.
        :return:
            the editor.
        """

        return toolkit.radio_buttons(self, attribute_type, parent)
