# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .composite_view_factory import CompositeViewFactory
from .form import Form


class SingleSubviewFactory(CompositeViewFactory):
    """ The SingleSubviewFactory class is a base class for composite views that
    can only have a single sub-view.
    """

    def __init__(self, *contents, **properties):
        """ Initialise the view.

        :param \*contents:
            is the list of the view's contents.  An individual item can either
            be a :class:`~dip.ui.ViewFactory` instance or a string.  Strings
            are are assumed to be the names of attributes within a model.  Such
            names may include one or more periods to specify an
            :term:`attribute path`.
        :param \*\*properties:
            are keyword arguments used as property names and values that are
            applied to the view.
        """

        nr_items = len(contents)

        if nr_items == 0:
            raise ValueError(
                    "{0} has no contents".format(type(self).__name__))

        # If there is more than one item, or the single item isn't a layout,
        # then wrap the contents in a single form.
        content = contents[0]

        if nr_items > 1 or (nr_items == 1 and not isinstance(content, CompositeViewFactory)):
            content = Form(*contents)

        super(SingleSubviewFactory, self).__init__(content, **properties)
