# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import Bool, Instance, Model, Str, TypeFactory

from .editor_factory import EditorFactory


class TableColumn(Model):
    """ The TableColumn class represents the meta-data of a column of a table.
    """

    # The name of attribute that the column is bound to.  It will be empty if a
    # row is a list rather than a model.
    bind_to = Str()

    # The type of the column.  It is ignored unless a row is a list of
    # :class:`~dip.model.Any` values.
    column_type = Instance(TypeFactory)

    # This is set if the values in the column are editable.
    editable = Bool(True)

    # The factory for the editor created to edit a value in the column.  It
    # will default to the editor factory provided by the toolkit for the type
    # of the value.
    editor_factory = Instance(EditorFactory)

    # The label of the column.  It will default to a value derived from the
    # name of the attribute that the column is bound to.
    label = Str()

    @label.getter
    def label(self):
        """ The getter for the column label. """

        # Use anything that has been explicitly set.
        if self._label != '':
            return self._label

        if self.bind_to != '':
            return EditorFactory.get_natural_name(self.bind_to)

        return ""
