# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .i_text_edit_editor import ITextEditEditor
from .editor_factory import EditorFactory


class TextEdit(EditorFactory):
    """ The TextEdit class implements a text editor editor factory for string
    attributes.
    """

    # The specific interface that the view implements.
    view_interface = ITextEditEditor

    def create_editor(self, attribute_type, toolkit, parent):
        """ Create the editor.

        :param attribute_type:
            the type of the attribute the factory is being asked to handle.  It
            should be a :class:`~dip.model.Str`.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            editor.
        :param parent:
            is the optional parent widget.
        :return:
            the editor.
        """

        return toolkit.text_edit(self, attribute_type, parent)
