# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QPoint, Qt
from PyQt4.QtGui import QButtonGroup
from PyQt4.QtTest import QTest

from dip.automate import IAutomatedEditor
from dip.model import adapt, Adapter, isadapted
from dip.ui import IEditor


@adapt(QButtonGroup, to=IAutomatedEditor)
class QButtonGroupAutomatedEditorAdapter(Adapter):
    """ An adapter to implement IAutomatedEditor for the Qt editor. """

    def simulate_set(self, id, delay, value):
        """ Simulate the user setting the editor value.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param value:
            is the value to set.  If the QButtonGroup, or it's parent,
            implements IEditor then the value must be valid for the attribute
            type.  Otherwise the value must be the integer identifier of the
            radio button.
        """

        button_group = self.adaptee

        # The three cases are an existing QButtonGroup bound using the
        # RadioButtons factory, a new QButtonGroup created by the RadioButtons
        # factory, and a QButtonGroup created by a non-dip application.
        if isadapted(button_group, IEditor):
            editor = button_group
        else:
            parent = button_group.parent()
            if parent is not None and isadapted(parent, IEditor):
                editor = parent
            else:
                editor = None

        if editor is not None:
            try:
                button_id = IEditor(editor).attribute_type.members.index(value)
            except ValueError:
                button_id = -1
        else:
            button_id = value

        button = button_group.button(button_id)
        if button is None:
            raise ValueError(
                    "{0} is an invalid value for the QButtonGroup "
                    "'{1}'".format(value, id))

        QTest.mouseClick(button, Qt.LeftButton, Qt.NoModifier, QPoint(), delay)
