# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QRegExp, Qt
from PyQt4.QtGui import QLineEdit, QRegExpValidator
from PyQt4.QtTest import QTest

from dip.automate import IAutomatedEditor
from dip.model import adapt, Adapter
from dip.ui import BaseEditorAdapter, ILineEditEditor


@adapt(QLineEdit, to=ILineEditEditor)
class QLineEditILineEditEditorAdapter(BaseEditorAdapter):
    """ An adapter to implement IEditor for the widget. """

    def configure(self):
        """ Configure the editor. """

        widget = self.adaptee

        if self.factory.read_only:
            widget.setReadOnly(True)
        else:
            # Get a validator factory from the editor factory or the type's
            # meta-data.  If the validator is a string then assume it is a
            # regular expression.
            validator = self.factory.validator
            if validator is None:
                validator = self.attribute_type.metadata.get('validator')

            if validator is not None:
                if isinstance(validator, str):
                    validator = QRegExpValidator(
                            QRegExp(validator, syntax=QRegExp.RegExp2), widget)
                else:
                    validator = validator(widget)

                widget.setValidator(validator)

        super(QLineEditILineEditEditorAdapter, self).configure()

    @ILineEditEditor.value.getter
    def value(self):
        """ The getter for the editor's value. """

        return unicode(self.adaptee.text())

    @value.setter
    def value(self, value):
        """ The setter for the editor's value. """

        self.adaptee.setText(value)

    @ILineEditEditor.invalid_reason.getter
    def invalid_reason(self):
        """ The getter for the invalid reason. """

        widget = self.adaptee

        if widget.hasAcceptableInput():
            invalid_reason = ''

            # Determine if a value is required.
            required = self.factory.required
            if required == 'meta-data':
                required = self.attribute_type.metadata.get('required', 'no')

            if required != 'no':
                value = unicode(widget.text())

                if required == 'stripped':
                    if value == '' or value.strip() != value:
                        invalid_reason = "a value without leading or " \
                                "trailing spaces is required"
                elif value == '':
                    invalid_reason = "a value is required"
        else:
            # Get a proper reason from the validator if it can provide one.
            validator = widget.validator()
            try:
                invalid_reason = validator.dip_invalid_reason
            except AttributeError:
                invalid_reason = "has an invalid format"

        return invalid_reason

    @BaseEditorAdapter.change_signal.getter
    def change_signal(self):
        """ Get the editor's change signal. """

        return self.adaptee.textEdited


@adapt(QLineEdit, to=IAutomatedEditor)
class QLineEditIAutomatedEditorAdapter(Adapter):
    """ An adapter to implement IAutomatedEditor for the widget. """

    def simulate_set(self, id, delay, value):
        """ Simulate the user setting the editor value.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param value:
            is the value to set.
        """

        widget = self.adaptee

        QTest.keyClicks(widget, 'a', Qt.ControlModifier, delay)
        QTest.keyClicks(widget, value, Qt.NoModifier, delay)
