# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import Qt
from PyQt4.QtGui import QMenu
from PyQt4.QtTest import QTest

from dip.automate import AutomationError, IAutomatedActionTrigger
from dip.model import adapt, Adapter


@adapt(QMenu, to=IAutomatedActionTrigger)
class QMenuIAutomatedActionTriggerAdapter(Adapter):
    """ The QMenuIAutomatedActionTriggerAdapter adapts a
    :class:`~PyQt4.QtGui.QMenu` to the
    :class:`~dip.shell.IAutomatedActionTrigger` interface.
    """

    def simulate_trigger(self, id, delay, action_id):
        """ Simulate the user triggering a menu action.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param action_id:
            is the identifier of the action.
        """

        widget = self.adaptee

        # Find the visible menu item that contains the action.
        for action in widget.actions():
            if action.isVisible() and action.objectName() == action_id:
                break
        else:
            raise AutomationError(id, 'trigger',
                    "unknown menu id '{0}'".format(action_id))

        pos = widget.actionGeometry(action).center()

        QTest.mouseClick(widget, Qt.LeftButton, pos=pos, delay=delay)
