# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import Qt
from PyQt4.QtGui import QMenuBar
from PyQt4.QtTest import QTest

from dip.automate import AutomationError, IAutomatedActionTrigger
from dip.model import adapt, Adapter


@adapt(QMenuBar, to=IAutomatedActionTrigger)
class QMenuBarIAutomatedActionTriggerAdapter(Adapter):
    """ The QMenuBarIAutomatedActionTriggerAdapter adapts a
    :class:`~PyQt4.QtGui.QMenuBar` to the
    :class:`~dip.shell.IAutomatedActionTrigger` interface.
    """

    def simulate_trigger(self, id, delay, action_id):
        """ Simulate the user triggering a menu bar action.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param action_id:
            is the identifier of the action.
        """

        widget = self.adaptee

        # Find the visible menu that contains the action.
        # FIXME: Shouldn't this be a bit more recursive?
        for action in widget.actions():
            if action.isVisible():
                menu = action.menu()

                for menu_action in menu.actions():
                    if menu_action.objectName() == action_id:
                        break
                else:
                    continue

                break
        else:
            raise AutomationError(id, 'trigger',
                    "unknown menu id '{0}'".format(action_id))

        # FIXME: There doesn't seem to be any way to work out where on a
        # FIXME: QMenuBar you should click for a particular QMenu.  Therefore
        # FIXME: we try and use an Alt key.  If there isn't one then we just
        # FIXME: trigger the action.

        title = unicode(menu.title())
        amp = title.find('&')

        if amp < 0 or amp + 1 == len(title):
            # There is no Alt key.
            QTest.qWait(delay)
            menu_action.trigger()
        else:
            QTest.keyClick(widget, title[amp + 1], Qt.AltModifier, delay)

            # Delegate to the menu.
            IAutomatedActionTrigger(menu).simulate_trigger(id, delay, action_id)
