# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import Qt
from PyQt4.QtGui import QSpinBox
from PyQt4.QtTest import QTest

from dip.automate import IAutomatedEditor
from dip.model import adapt, Adapter
from dip.ui import BaseEditorAdapter, ISpinBoxEditor


@adapt(QSpinBox, to=ISpinBoxEditor)
class QSpinBoxISpinBoxEditorAdapter(BaseEditorAdapter):
    """ An adapter to implement IEditor for the widget. """

    def configure(self):
        """ Configure the editor.
        """

        widget = self.adaptee

        if self.factory.read_only:
            widget.setReadOnly(True)

        blocked = widget.blockSignals(True)
        super(QSpinBoxISpinBoxEditorAdapter, self).configure()
        widget.blockSignals(blocked)

    @ISpinBoxEditor.value.getter
    def value(self):
        """ The getter for the editor's value. """

        return self.adaptee.value()

    @value.setter
    def value(self, value):
        """ The setter for the editor's value. """

        widget = self.adaptee

        blocked = widget.blockSignals(True)
        widget.setValue(value)
        widget.blockSignals(blocked)

    @BaseEditorAdapter.change_signal.getter
    def change_signal(self):
        """ Get the editor's change signal. """

        return self.adaptee.valueChanged


@adapt(QSpinBox, to=IAutomatedEditor)
class QSpinBoxIAutomatedEditorAdapter(Adapter):
    """ An adapter to implement IAutomatedEditor for the widget. """

    def simulate_set(self, id, delay, value):
        """ Simulate the user setting the editor value.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param value:
            is the value to set.
        """

        widget = self.adaptee

        QTest.keyClicks(widget, "a", Qt.ControlModifier, delay)
        QTest.keyClicks(widget, str(value), Qt.NoModifier, delay)
