# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QPoint, Qt
from PyQt4.QtGui import QToolButton
from PyQt4.QtTest import QTest

from dip.automate import IAutomatedTrigger
from dip.model import adapt, Adapter
from dip.ui import BaseEditorAdapter, IToolButtonEditor


@adapt(QToolButton, to=IToolButtonEditor)
class QToolButtonIToolButtonEditorAdapter(BaseEditorAdapter):
    """ An adapter to implement IEditor for the widget. """

    # The label is embedded.
    label_policy = 'embedded'

    @IToolButtonEditor.value.getter
    def value(self):
        """ The getter for the editor's value. """

        # Any value will do as it is only used to pull the Trigger.
        return None

    @value.setter
    def value(self, value):
        """ The setter for the editor's value. """

        raise ValueError("cannot set the value of a QToolButton")

    @BaseEditorAdapter.change_signal.getter
    def change_signal(self):
        """ Get the editor's change signal. """

        return self.adaptee.clicked


@adapt(QToolButton, to=IAutomatedTrigger)
class QToolButtonIAutomatedTriggerAdapter(Adapter):
    """ An adapter to implement IAutomatedTrigger for the widget. """

    def simulate_trigger(self, id, delay):
        """ Simulate the user pulling the trigger

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        """

        QTest.mouseClick(self.adaptee, Qt.LeftButton, Qt.NoModifier, QPoint(),
                delay)
