# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QPoint, Qt
from PyQt4.QtGui import QWizard
from PyQt4.QtTest import QTest

from dip.automate import AutomationError, IAutomatedDialog
from dip.model import adapt, Adapter
from dip.ui import BaseViewAdapter, ICompositeView


@adapt(QWizard, to=ICompositeView)
class QWizardICompositeViewAdapter(BaseViewAdapter):
    """ An adapter to implement ICompositeView for the Qt view. """

    def configure(self):
        """ Configure the view.  This is called when everything else has been
        set up.
        """

        wizard = self.adaptee

        if wizard.options() & QWizard.HaveFinishButtonOnEarlyPages:
            for page_id in wizard.pageIds():
                wizard.page(page_id).setFinalPage(True)

        wizard.button(QWizard.FinishButton).clicked.connect(self._on_finish)

        # Do the standard configuration.
        super(QWizardICompositeViewAdapter, self).configure()

    def subviews(self):
        """ Return a sequence of sub-views, i.e. instances of
        :class:`~PyQt4.QtGui.QLayout` or :class:`~PyQt4.QtGui.QWidget` that
        implement or have been adapted to :class:`~dip.ui.IView`.

        :return:
            the sequence of sub-views.
        """

        wizard = self.adaptee

        subviews = []

        for page_id in wizard.pageIds():
            subviews.extend(ICompositeView(wizard.page(page_id)).subviews())

        return subviews

    def _on_finish(self):
        """ Invoked when the Finish button is clicked. """

        # Update the model if it wasn't being done automatically.
        if not self.controller.auto_update_model:
            self.controller.update_model()


@adapt(QWizard, to=IAutomatedDialog)
class QWizardIAutomatedDialogAdapter(Adapter):
    """ An adapter to implement IAutomatedDialog for the Qt dialog. """

    def simulate_click(self, id, delay, button):
        """ Simulate the user clicking a button.

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        :param button:
            is the :class:`~PyQt4.QtGui.QWizard.WizardButton` to click.
        """

        # Find the button widget.
        button_widget = self.adaptee.button(button)

        if button_widget is None:
            raise AutomationError(id, 'click',
                    "no {0} button in wizard".format(hex(button)))

        QTest.mouseClick(button_widget, Qt.LeftButton, Qt.NoModifier, QPoint(),
                delay)
