# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QWizardPage

from dip.model import adapt
from dip.ui import BaseViewAdapter, ICompositeView


@adapt(QWizardPage, to=ICompositeView)
class QWizardPageICompositeViewAdapter(BaseViewAdapter):
    """ An adapter to implement ICompositeView for the Qt view. """

    def configure(self):
        """ Configure the view.  This is called when everything else has been
        set up.
        """

        wizard_page = self.adaptee

        # The controller maintains the 'dip_is_complete' attribute which must
        # be returned by QWizardPage.isComplete().  We would normally
        # reimplement this in a sub-class, but we allow the binding of a plain
        # QWizardPage so we monkey patch it instead.
        def isComplete():
            return wizard_page.dip_is_complete

        wizard_page.isComplete = isComplete
        wizard_page.dip_is_complete = True

        # Do the standard configuration.
        super(QWizardPageICompositeViewAdapter, self).configure()

    def subviews(self):
        """ Return a sequence of sub-views, i.e. instances of
        :class:`~PyQt4.QtGui.QLayout` or :class:`~PyQt4.QtGui.QWidget` that
        implement or have been adapted to :class:`~dip.ui.IView`.

        :return:
            the sequence of sub-views.
        """

        layout = self.adaptee.layout()

        return [] if layout is None else ICompositeView(layout).subviews()
