# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .composite_view_factory import CompositeViewFactory


class Wizard(CompositeViewFactory):
    """ The Wizard class implements a :class:`~PyQt4.QtGui.QWizard` based
    wizard.
    """

    def create_view(self, controller, toolkit, parent):
        """ Create the view for a model.

        :param controller:
            is the controller.
        :param toolkit:
            is the :class:`~dip.ui.IToolkit` implementation used to create the
            dialog.
        :param parent:
            is the optional parent widget.
        :return:
            the :class:`~PyQt4.QtGui.QWizard` instance that is the view's
            implementation.
        """

        pages = self.create_subviews(controller, toolkit, None)
        view = toolkit.wizard(self, pages, parent)
        self.bind(view, controller, toolkit)

        return view

    def create_controller(self):
        """ Create an implementation of :class:`~dip.ui.IController`.

        :return:
            the controller.
        """

        from .wizard_controller import WizardController

        # Delay the updating of the model until the wizard is finished.
        return WizardController(auto_update_model=False)

    @CompositeViewFactory.id.default
    def id(self):
        """ The default value of id. """

        return 'dip.wizard'
