# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import adapt, Adapter
from dip.shell import IDisplay, IShellObject

from .i_py_module import IPyModule


@adapt(IPyModule, to=IShellObject)
class IPyModuleIShellObjectAdapter(Adapter):
    """ The IPyModuleIShellObjectAdapter adapts a Python module to the
    IShellObject interface.
    """

    @IShellObject.location.observer
    def location(self, change):
        """ Invoked when the location of the object changes. """

        location = change.new

        if location is None:
            name = ''
        else:
            # If the location implements IDisplay then use it.
            idisplay = IDisplay(location, exception=False)
            if idisplay is None:
                name = location.location
            else:
                name = idisplay.name
                self.short_name = idisplay.short_name

        self.name = name if name != '' else "Untitled"
