# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.plugins import ContributionTo, Plugin


class PyEditorPlugin(Plugin):
    """ The PyEditorPlugin class is the plugin definition for the simple Python
    editor.
    """

    # The description of the plugin as it will appear to the user.
    description = "Python editor"

    # The identifier of the plugin.
    id = 'dip.examples.py_editor'

    # The codecs contributed by this plugin.
    codecs = ContributionTo('dip.io.codecs')

    # The shell objects contributed by this plugin.
    objects = ContributionTo('dip.shell.objects')

    # The tools contributed by this plugin.
    tools = ContributionTo('dip.shell.tools')

    @codecs.default
    def codecs(self):
        """ Create the codecs factories. """

        from py_editor import PyModuleCodecsFactory

        return [PyModuleCodecsFactory()]

    @objects.default
    def objects(self):
        """ Create the shell object factories. """

        from py_editor import PyModuleFactory

        return [PyModuleFactory()]

    @tools.default
    def tools(self):
        """ Create the tool factories. """

        from py_editor import PyEditorFactory

        return [PyEditorFactory()]
