# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.model import implements, Instance, Model, Str

from .i_py_module import IPyModule
from .py_editor import PyEditor


@implements(IPyModule)
class PyModule(Model):
    """ The PyModule class is the default implementation of a Python module.
    """

    # For efficiency reasons we are going to use the editor itself (if it has
    # been created) to hold the text of the module.
    editor = Instance(PyEditor)

    # This is the module's text that needs to be stored in the editor as soon
    # as it is created.
    _pending_text = Str()

    @IPyModule.text.getter
    def text(self):
        """ The getter of the text. """

        return self._pending_text if self.editor is None else self.editor.text()

    @text.setter
    def text(self, text):
        """ The setter of the text. """

        if self.editor is None:
            self._pending_text = text
        else:
            self.editor.setText(text)

    @editor.setter
    def editor(self, editor):
        """ The setter of the editor. """

        # Load any pending text.
        editor.setText(self._pending_text)
        self._pending_text = ''
