# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QByteArray

from dip.io import IDecoder, IEncoder
from dip.model import implements, Model


@implements(IDecoder)
class PyModuleDecoder(Model):
    """ The PyModuleDecoder class implements a decoder for a Python module.
    """

    def decode(self, obj, source, location):
        """ A Python module is decoded from a byte stream.

        :param obj:
            is the Python module to populate from the decoded byte stream.
        :param source:
            is an iterator that will return the byte stream to be decoded.
        :param location:
            is the storage location where the encoded object is being read
            from.  It is mainly used for error reporting.
        :return:
            the Python module.
        """

        data = QByteArray()

        for block in source:
            data.append(block)

        # Assume the module is UTF-8 encoded.  A more complete implementation
        # would support PEP 263 by peeking at the first couple of lines.
        obj.text = str(data, encoding='utf8')

        return obj


@implements(IEncoder)
class PyModuleEncoder(Model):
    """ The PyModuleEncoder class implements an encoder for a Python module.
    """

    def encode(self, obj, location):
        """ A Python module is encoded as a byte stream.

        :param obj:
            is the Python module to encode.
        :param location:
            is the storage location where the encoded object will be written
            to.  It is mainly used for error reporting.
        :return:
            the next section of the encoded byte stream.
        """

        # Assume the module is UTF-8 encoded.  A more complete implementation
        # would support PEP 263 by peeking at the first couple of lines.
        yield obj.text.encode('utf8')
