# Copyright (c) 2010 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from dip.io import ICodecsFactory
from dip.model import implements, Model

from .i_py_module import IPyModule
from .py_module_codecs import PyModuleDecoder, PyModuleEncoder


@implements(ICodecsFactory)
class PyModuleCodecsFactory(Model):
    """ The PyModuleCodecsFactory class is the factory for the codecs used to
    serialise a Python module.
    """

    # The identifier of the format.
    id = 'dip.examples.py_module.format'

    # The name of the format.
    name = "Python module"

    # The filter used with :class:`PyQt4.QtGui.QFileDialog`.
    filter = "Python files (*.py *.pyw)"

    def decodes(self, obj):
        """ Determine if the object can be decoded.

        :param obj:
            is the object.
        :return:
            ``True`` if the object can be decoded.
        """

        return isinstance(obj, IPyModule)

    def decoder(self):
        """ A new instance of the object decoder is created and returned.

        :return:
            a new instance of the object decoder.
        """

        return PyModuleDecoder(factory=self)

    def encodes(self, obj):
        """ Determine if the object can be encoded.

        :param obj:
            is the object.
        :return:
            ``True`` if the object can be encoded.
        """

        return isinstance(obj, IPyModule)

    def encoder(self):
        """ A new instance of the object encoder is created and returned.

        :return:
            a new instance of the object encoder.
        """

        return PyModuleEncoder(factory=self)
