from dip.plugins import ContributionTo, Plugin, Service

from recipes import IRecipeChooser
from stock import IStockLevels

class RecipeChooserPlugin(Plugin):
    """ The RecipeChooserPlugin class is a plugin that publishes a service
    that implements the IRecipeChooser interface. """

    # The identifier of the plugin.
    id = 'recipes.plugins.chooser'

    # The description of the plugin as it will appear to the user.
    description = "The default recipes chooser plugin"

    # The contribution of the service.
    recipe_chooser = ContributionTo('dip.plugins.services')

    @recipe_chooser.default
    def recipe_chooser(self):
        """ Create the recipe chooser service. """

        from recipes.recipe_chooser import RecipeChooser

        stock_levels = self.service(IStockLevels)

        chooser = RecipeChooser(stock_levels=stock_levels)

        self.bind_extension_point('recipes.recipes', chooser, 'recipes')

        service = Service(interface=IRecipeChooser, implementation=chooser)

        return [service]
