# Copyright (c) 2009 Riverbank Computing Limited.


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from dip.model import Model, Subclass, ValidationError


class TestSubclassType(unittest.TestCase):
    """ This tests the Subclass type. """

    def test_invalid_string_subclass_type(self):
        """ Invalid Subclass type string. """

        class Klass(Model):
            attr = Subclass('foo.bar.baz')

        with self.assertRaises(AttributeError):
            Klass(attr=False)

    def test_valid_string_subclass_type(self):
        """ Valid Subclass type string. """

        class Klass(Model):
            attr = Subclass('dip.model.Model')

        value = Model
        k = Klass(attr=value)

        self.assertIs(k.attr, value)

    def test_invalid_subclass_type(self):
        """ Invalid Subclass type specification. """

        class Klass(Model):
            attr = Subclass(None)

        with self.assertRaises(TypeError):
            Klass(attr=0)

    def test_valid_subclass_type(self):
        """ Valid Subclass type. """

        # Create a valid test class and data.
        class Klass(Model):
            attr = Subclass(Model)

        class InvalidClass: pass

        valid_value = Klass
        invalid_value = InvalidClass()

        # Verify a valid value.
        k = Klass(attr=valid_value)
        self.assertIs(k.attr, valid_value)

        # Verify a None value.
        k = Klass(attr=None)
        self.assertIsNone(k.attr)

        # Verify an invalid value.
        with self.assertRaises(ValidationError):
            Klass(attr=invalid_value)

        # Verify rebinding a valid value.
        k = Klass()
        k.attr = valid_value
        self.assertIs(k.attr, valid_value)

        # Verify rebinding a None value.
        k = Klass()
        k.attr = None
        self.assertIsNone(k.attr)

        # Verify rebinding an invalid value.
        k = Klass()
        with self.assertRaises(ValidationError):
            k.attr = invalid_value


if __name__ == '__main__':
    unittest.main()
