# Copyright (c) 2010 Riverbank Computing Limited.


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from dip.model import List, Model
from dip.plugins import Plugin, PluginManager


class Capture(Model):
    """ A utility class for binding to an extension point. """
    capture = List()


class TestPluginManager(unittest.TestCase):
    """ This tests the default plugin manager's handling of plugins. """

    def setUp(self):
        """ Create a Capture instance. """

        self.capture = Capture()

    def test_bootstrap(self):
        """ Test the bootstrap of the root extension point. """

        # This implicitly tests binding an extension point.
        plugin_manager = PluginManager()
        plugin_manager.bind_extension_point('dip.plugins.extension_points',
                self.capture, 'capture')

        ep = self.capture.capture[0]

        self.assertEqual(ep.id, 'dip.plugins.extension_points')
        self.assertIs(ep, ep.contributions[0])

    def test_enable_plugin(self):
        """ Test the enabling of plugins. """

        class TestPlugin(Plugin):
            id = 'test.plugin'

        plugin_manager = PluginManager()
        plugin_manager.bind_extension_point('dip.plugins.plugins',
                self.capture, 'capture')

        # This implicitly tests contributing to an extension point.
        plugin_manager.contribute('dip.plugins.plugins',
                TestPlugin(plugin_manager=plugin_manager))

        plugin = self.capture.capture[0]

        self.assertFalse(plugin.enabled)
        plugin_manager.enable_plugins()
        self.assertTrue(plugin.enabled)


if __name__ == '__main__':
    unittest.main()
