# Copyright (c) 2010 Riverbank Computing Limited.


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from dip.model import Any, List, Model
from dip.plugins import ContributionTo, Plugin, PluginManager


class Capture(Model):
    """ A utility class for binding to an extension point. """
    capture = List()


class TestPlugins(unittest.TestCase):
    """ This tests the default plugin manager's support for plugins. """

    def setUp(self):
        """ Create a Capture instance. """

        self.capture = Capture()

    def test_contribution_to(self):
        """ Test ContributionTo. """

        class TestPlugin(Plugin):
            id = 'test.plugin'
            injection = Any()

            contrib = ContributionTo('test.ep')

            @contrib.default
            def contrib(self):
                return [self.injection]

        plugin_manager = PluginManager()

        plugin_manager.bind_extension_point('test.ep', self.capture, 'capture')

        injection = object()

        plugin_manager.contribute('dip.plugins.plugins',
                TestPlugin(plugin_manager=plugin_manager, injection=injection))

        # Check the contribution doesn't happen until the plugin is enabled.
        self.assertEqual(len(self.capture.capture), 0)
        plugin_manager.enable_plugins()
        self.assertEqual(len(self.capture.capture), 1)

        self.assertIs(self.capture.capture[0], injection)

        # Check that enabling again doesn't do anything.
        plugin_manager.enable_plugins()
        self.assertEqual(len(self.capture.capture), 1)

    def test_contributions(self):
        """ Test a plugin's ability to create extension points dynamically. """

        class TestPlugin(Plugin):
            id = 'test.plugin'

            def contributions(self):
                yield 'test.odd', [1, 3]

        plugin_manager = PluginManager()

        plugin_manager.bind_extension_point('dip.plugins.extension_points',
                self.capture, 'capture')

        plugin_manager.contribute('dip.plugins.plugins',
                TestPlugin(plugin_manager=plugin_manager))

        plugin_manager.enable_plugins()

        # Find the extension point.
        for ep in self.capture.capture:
            if ep.id == 'test.odd':
                break
        else:
            ep = None

        self.assertIsNotNone(ep)
        self.assertListEqual(ep.contributions, [1, 3])


if __name__ == '__main__':
    unittest.main()
