# Copyright (c) 2010 Riverbank Computing Limited.


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from dip.model import implements, Interface, Model
from dip.plugins import PluginManager, Service


class ITestService(Interface):
    """ A test service interface. """
    pass


@implements(ITestService)
class TestService(Model):
    """ A test service. """
    pass


class TestServices(unittest.TestCase):
    """ This tests the default plugin manager's support for services. """

    def test_no_service(self):
        """ Test requesting a non-existent service. """

        plugin_manager = PluginManager()

        with self.assertRaises(TypeError):
            plugin_manager.service(ITestService)

    def test_service(self):
        """ Test with an existing service. """

        plugin_manager = PluginManager()

        impl = TestService()

        plugin_manager.contribute('dip.plugins.services',
                Service(interface=ITestService, implementation=impl))

        service = plugin_manager.service(ITestService)
        self.assertIs(service, impl)

    def test_multiple_services(self):
        """ Test more than one service. """

        plugin_manager = PluginManager()

        impl1 = TestService()
        impl2 = TestService()

        plugin_manager.contribute('dip.plugins.services',
                Service(interface=ITestService, implementation=impl1),
                Service(interface=ITestService, implementation=impl2))

        service = plugin_manager.service(ITestService)
        self.assertIs(service, impl1)

    def test_service_chooser(self):
        """ Test a non-default service chooser. """

        class TestPluginManager(PluginManager):
            def choose_service(self, interface, services):
                return services[-1] if len(services) > 0 else None

        plugin_manager = TestPluginManager()

        impl1 = TestService()
        impl2 = TestService()

        plugin_manager.contribute('dip.plugins.services',
                Service(interface=ITestService, implementation=impl1),
                Service(interface=ITestService, implementation=impl2))

        service = plugin_manager.service(ITestService)
        self.assertIs(service, impl2)


if __name__ == '__main__':
    unittest.main()
