# Copyright (c) 2010 Riverbank Computing Limited.


if __name__ == '__main__':
    import sys
    from PyQt4.QtGui import QApplication

    app = QApplication(sys.argv)


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from PyQt4.QtGui import QDialog, QDialogButtonBox

from dip.automate import Robot
from dip.ui import Dialog, HBox
from dip.ui.toolkits.qt import QtToolkit


class TestDialog(unittest.TestCase):
    """ This tests the Dialog view. """

    def test_ok(self):
        """ Test Dialog Ok button. """

        model = dict(attr=10)
        view = Dialog(HBox(), id='Dialog.ok')
        ui = view(model, QtToolkit())

        robot = Robot()
        robot.record('Dialog.ok:attr', 'set', 20)
        robot.record('Dialog.ok', 'click', QDialogButtonBox.Ok)
        robot.play(after=0)

        rc = ui.exec_()

        # Verify that the dialog returned the expected value and that the
        # model was updated.
        self.assertEqual(rc, QDialog.Accepted)
        self.assertEqual(model['attr'], 20)

    def test_cancel(self):
        """ Test Dialog Cancel button. """

        model = dict(attr=10)
        view = Dialog(HBox(), id='Dialog.cancel')
        ui = view(model, QtToolkit())

        robot = Robot()
        robot.record('Dialog.cancel:attr', 'set', 20)
        robot.record('Dialog.cancel', 'click', QDialogButtonBox.Cancel)
        robot.play(after=0)

        rc = ui.exec_()

        # Verify that the dialog returned the expected value and that the
        # model was not updated.
        self.assertEqual(rc, QDialog.Rejected)
        self.assertEqual(model['attr'], 10)


if __name__ == '__main__':
    unittest.main()
