# Copyright (c) 2011 Riverbank Computing Limited.


if __name__ == '__main__':
    import sys
    from PyQt4.QtGui import QApplication

    app = QApplication(sys.argv)


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from PyQt4.QtTest import QTest

from dip.automate import AutomationError, Robot
from dip.model import List, Model, Str
from dip.ui import CollectionButtons, ListWidget, VBox
from dip.ui.toolkits.qt import QtToolkit


# The test model.
class TestModel(Model):
    attr = List(Str())

model = None


# The test GUI.
view = VBox(CollectionButtons('attr'), ListWidget('attr'), id='ListEditor')

ui = None


class TestListWidgetEditor(unittest.TestCase):
    """ This tests the list widget editor. """

    def setUp(self):
        """ Initialise the list widget, creating it if necessary. """

        # Create it if this is the first call.
        global model, ui

        if model is None:
            model = TestModel()

        if ui is None:
            ui = view(model, QtToolkit())

        model.attr = []

        ui.show()
        QTest.qWaitForWindowShown(ui)
        ui.activateWindow()

    def tearDown(self):
        """ Tidy up the list widget. """

        ui.hide()

    def test_set(self):
        """ Test set. """

        model.attr = ["Old"]
        Robot.simulate('ListEditor:attr', 'set', "New", 0)
        self.assertEqual(model.attr, ["New"])

    def test_set_invalid_index(self):
        """ Test set with an invalid index. """

        with self.assertRaises(AutomationError):
            Robot.simulate('ListEditor:attr', 'set', "Invalid", -1)

    def test_add(self):
        """ Test adding using a tool button. """

        Robot.simulate('ListEditor:attr.add', 'trigger')
        Robot.simulate('ListEditor:attr', 'set', "New")
        self.assertEqual(model.attr, ["New"])

    def test_remove(self):
        """ Test removing using a tool button. """

        model.attr = ["First", "Second"]
        Robot.simulate('ListEditor:attr', 'select', 0)
        Robot.simulate('ListEditor:attr.remove', 'trigger')
        self.assertEqual(model.attr, ["Second"])

    def test_up(self):
        """ Test moving up. """

        model.attr = ["First", "Second", "Third"]
        Robot.simulate('ListEditor:attr', 'select', 1)
        Robot.simulate('ListEditor:attr.up', 'trigger')
        self.assertEqual(model.attr, ["Second", "First", "Third"])

    def test_down(self):
        """ Test moving down. """

        model.attr = ["First", "Second", "Third"]
        Robot.simulate('ListEditor:attr', 'select', 1)
        Robot.simulate('ListEditor:attr.down', 'trigger')
        self.assertEqual(model.attr, ["First", "Third", "Second"])


if __name__ == '__main__':
    unittest.main()
