# Copyright (c) 2011 Riverbank Computing Limited.


if __name__ == '__main__':
    import sys
    from PyQt4.QtGui import QApplication

    app = QApplication(sys.argv)


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from dip.automate import Robot
from dip.ui import Form
from dip.ui.toolkits.qt import QtToolkit


class TestMapping(unittest.TestCase):
    """ This tests views based on a Python mapping type. """

    def test_bool(self):
        """ Test bool attributes of a mapping. """

        model = dict(attr=False)
        view = Form(id='Mapping.bool')
        ui = view(model, QtToolkit())
        ui.show()

        Robot.simulate('Mapping.bool:attr', 'set', True)
        self.assertIs(model['attr'], True)

    def test_int(self):
        """ Test integer attributes of a mapping. """

        model = dict(attr=10)
        view = Form(id='Mapping.int')
        ui = view(model, QtToolkit())
        ui.show()

        Robot.simulate('Mapping.int:attr', 'set', 20)
        self.assertEqual(model['attr'], 20)

    def test_float(self):
        """ Test float attributes of a mapping. """

        model = dict(attr=10.0)
        view = Form(id='Mapping.float')
        ui = view(model, QtToolkit())
        ui.show()

        Robot.simulate('Mapping.float:attr', 'set', 20)
        self.assertEqual(model['attr'], 20.0)

    def test_str(self):
        """ Test string attributes of a mapping. """

        model = dict(attr='default')
        view = Form(id='Mapping.str')
        ui = view(model, QtToolkit())
        ui.show()

        Robot.simulate('Mapping.str:attr', 'set', 'non-default')
        self.assertEqual(model['attr'], 'non-default')

    def test_list(self):
        """ Test list attributes of a mapping. """

        model = dict(attr=['first', 'second'])
        view = Form(id='Mapping.list')
        ui = view(model, QtToolkit())
        ui.show()

        Robot.simulate('Mapping.list:attr', 'set', '2nd', 1)
        self.assertEqual(model['attr'], ['first', '2nd'])


if __name__ == '__main__':
    unittest.main()
