# Copyright (c) 2011 Riverbank Computing Limited.


if __name__ == '__main__':
    import sys
    from PyQt4.QtGui import QApplication

    app = QApplication(sys.argv)


try:
    import unittest2 as unittest
except ImportError:
    import unittest

from PyQt4.QtGui import QMainWindow
from PyQt4.QtTest import QTest

from dip.automate import Robot
from dip.ui import Action, ActionCollection, MenuBar
from dip.ui.toolkits.qt import QtToolkit


class MainWindow(QMainWindow):
    """ This is the widget used to test menu bars and menus. """

    def __init__(self):
        """ Initialise. """

        super(MainWindow, self).__init__()

        self.reset()

        alt_action = Action(id='Menus.alt_action', parent=self,
                text="Alt Action", triggered=self._on_alt_action_triggered)
        alt_actions = ActionCollection(title="&Alt Actions",
                members=['Menus.alt_action'])

        plain_action = Action(id='Menus.plain_action', parent=self,
                text="Plain Action", triggered=self._on_plain_action_triggered)
        plain_actions = ActionCollection(title="Plain Actions",
                members=['Menus.plain_action'])

        menu_bar_factory = MenuBar(alt_actions, plain_actions, id='MenuBar')
        menu_bar = menu_bar_factory(QtToolkit(), alt_action, plain_action)
        self.setMenuBar(menu_bar)

    def reset(self):
        """ Reset the internal state. """

        self.alt_action_triggered = False
        self.plain_action_triggered = False

    def _on_alt_action_triggered(self):
        """ Invoked when the alt action is triggered. """

        self.alt_action_triggered = True

    def _on_plain_action_triggered(self):
        """ Invoked when the plain action is triggered. """

        self.plain_action_triggered = True

ui = None


class TestMenus(unittest.TestCase):
    """ This tests menu bars and menus. """

    def setUp(self):
        """ Initialise the test widget, creating it if necessary. """

        # Create it if this is the first call.
        global ui

        if ui is None:
            ui = MainWindow()

        ui.reset()

        ui.show()
        QTest.qWaitForWindowShown(ui)
        ui.activateWindow()

    def tearDown(self):
        """ Tidy up the test widget. """

        ui.hide()

    def test_AltMenu(self):
        """ Test a menu that can use an Alt key to select. """

        Robot.simulate('MenuBar', 'trigger', 'Menus.alt_action')
        self.assertTrue(ui.alt_action_triggered)

    def test_PlainMenu(self):
        """ Test a menu that cannot use an Alt key to select. """

        Robot.simulate('MenuBar', 'trigger', 'Menus.plain_action')
        self.assertTrue(ui.plain_action_triggered)


if __name__ == '__main__':
    unittest.main()
